import ReactDOM from 'react-dom';
import React , {Component}from 'react';
import './index.css';
import SwaggerUI from 'swagger-ui'
import 'swagger-ui/dist/swagger-ui.css';
import PortalLayout from './PortalLayout'
import Response from './components/Response'
import "./App.css"
import Chip from '@material-ui/core/Chip';
import Button from '@material-ui/core/Button';
import IconButton from '@material-ui/core/IconButton';
import Menu from '@material-ui/core/Menu';
import MenuItem from '@material-ui/core/MenuItem';
import Dialog from '@material-ui/core/Dialog';
import DialogActions from '@material-ui/core/DialogActions';
import DialogContent from '@material-ui/core/DialogContent';
import DialogTitle from '@material-ui/core/DialogTitle';
import { Prism as SyntaxHighlighter } from "react-syntax-highlighter";
import { CopyToClipboard } from 'react-copy-to-clipboard';
import TextField from '@material-ui/core/TextField';
const auth0 = require('auth0-js');
const Auth = require('./Auth/Auth.js').default;
window.auth0 = auth0;

window.auth = new Auth({
    clientID: window.__auth__.clientId,
    domain: window.__auth__.domain,
    audience: window.__auth__.audience
});

const authBodyJsonText =
`{
    "grant_type": "password",
    "username": "YOUR_EMAIL_ADDRESS",
    "password": "YOUR_PASSWORD",
    "audience": "${window.__auth__.audience}",
    "client_id": "${window.__auth__.clientId}"
}`;

const authBodyFederationJsonText =
    `{
    "grant_type": "refresh_token",
    "refresh_token": "YOUR_REFRESH_TOKEN",
    "client_id": "${window.__auth__.refreshTokenClientId}"
}`;


let serverHeight = null;


class App extends Component {
    constructor(props){
        super(props);
        this.state = {authMenuAnchor: null, authenticationDialogState: false, authenticationDialog: "AUTHENTICATION"};
    }

    handleMenu = event => {
        this.setState({ authMenuAnchor: event.currentTarget });
        const close = () => {
          this.handleClose();
          document.body.removeEventListener("click", close);
        };
        document.body.addEventListener("click", close);
    };

    handleClose = () => {
        this.setState({ authMenuAnchor: null });
    };

    authenticationDialogRefreshToken = () => {
        this.setState({authenticationDialog: "REFRESH-TOKEN"});
    };

    authenticationDialogRegularToken = () => {
        this.setState({authenticationDialog: "AUTHENTICATION"});
    };

    handleAuthenticationDialog = () => {
        this.setState({authenticationDialogOpen: true});
    };

    handleCloseAuthenticationDialog = () => {
        this.setState({authenticationDialogOpen: false, authenticationDialog: "AUTHENTICATION"});
    };

    setAccessToken = (event) => {
        this.setState({accessToken: event.currentTarget.value});
    };

    componentWillMount() {
        const integrator = {
          setHeader: (headerInfo) => {
              this.setState({headerInfo})
          },
          setServerEl: (el) => {
              if(el && serverHeight !== el.clientHeight){
                  serverHeight = el.clientHeight;
                  this.setState({serverHeight});
              }
          }
        };
        const Wrapper = (props) => {
          return <PortalLayout {...props} integrator={integrator}/>
        };

        const PortalPlugin = function() {
            return {
                components: {
                    PortalLayout: Wrapper,
                    response: Response
                }
            }
        };

        const launch = () => {
            SwaggerUI({
                dom_id: '#swagger-root',
                url: window.apiLocation.portal,
                requestInterceptor: (a) => {
                    const token = this.state.accessToken || (window.authResult && window.authResult.accessToken);
                    if(token){
                        a.headers["Authorization"] = `Bearer ${token}`;
                    }
                    return a;
                },
                plugins: [PortalPlugin],
                layout: "PortalLayout"
            });
        };

        window.auth.refreshSso().then((authResult) => {
            window.authResult = authResult;
            window.history.pushState({}, null, window.location.pathname)
        }, () => {}).then(launch, launch);
    }

    render(){
        const authMenuOpen = Boolean(this.state.authMenuAnchor);
        return <div>
            <header style={{height: 65, position: "fixed", left: 0, right: 0, backgroundColor: "#3f51b5",boxShadow: "0px 2px 4px -1px rgba(0,0,0,0.2), 0px 4px 5px 0px rgba(0,0,0,0.14), 0px 1px 10px 0px rgba(0,0,0,0.12)"}}>
                { this.state.headerInfo &&
                    <div>
                        <span style={{color: "#fff", marginLeft: "25px", fontSize: "24px"}}>{ this.state.headerInfo.title }</span>
                        <Chip label={this.state.headerInfo.version} className="version-chip" classes={{label: "version-chip"}} />
                        { this.state.headerInfo.url && <a target="_blank" href={ this.state.headerInfo.url } color="contrast" style={{color: "#fff", fontSize: "10px", position: "relative", top: "-10px", left: "10px"}}><span className="url"> { this.state.headerInfo.url } </span></a> }
                        <span style={{position: "absolute", right: "27px"}}>
                    {window.authResult &&
                    <span><IconButton
                        aria-haspopup="true"
                        onClick={this.handleMenu}
                        color="contrast"
                        style={{color: "#fff", float: "left", position: "relative", right: "40px", top: "-4px"}}
                    >
                        <svg style={{
                            fill: "currentColor", width: "1em", height: "1em", display: "inline-block", fontSize: "24px", transition: "fill 200ms cubic-bezier(0.4, 0, 0.2, 1) 0ms", userSelect: "none", flexShrink: 0
                        }}  focusable="false" viewBox="0 0 24 24" aria-hidden="true"><path
                            d="M12 2C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm0 3c1.66 0 3 1.34 3 3s-1.34 3-3 3-3-1.34-3-3 1.34-3 3-3zm0 14.2c-2.5 0-4.71-1.28-6-3.22.03-1.99 4-3.08 6-3.08 1.99 0 5.97 1.09 6 3.08-1.29 1.94-3.5 3.22-6 3.22z"/>
                        </svg>
                                </IconButton>
                                    <Menu
                                        anchorEl={this.state.authMenuAnchor}
                                        anchorOrigin={{vertical: 'top', horizontal: 'right',}}
                                        transformOrigin={{vertical: 'top', horizontal: 'right',}}
                                        open={authMenuOpen}
                                        onClose={() => console.log("test")}
                                    >
                                        <MenuItem>{window.authResult.idTokenPayload["http://cloud.netapp.com/user_metadata"].name}</MenuItem>
                                        <MenuItem onClick={() => window.auth.logout({returnTo: `${window.location.origin}/api-doc`})}>Logout</MenuItem>
                                    </Menu>
                                </span>}
                        </span>
                    </div>
                }
            </header>
            {this.state.serverHeight && <Button color="primary" onClick={this.handleAuthenticationDialog} style={{position: "absolute", right: "219px", top: this.state.serverHeight + 155 + "px"}}>
                Learn how to authenticate
            </Button>}


            <Dialog
                open={this.state.authenticationDialogOpen}
                keepMounted
                maxWidth="md"
                onClose={this.handleCloseAuthenticationDialog}
                aria-labelledby="alert-dialog-slide-title"
                aria-describedby="alert-dialog-slide-description"
                className="authentication-dialog"
            >
                <DialogTitle id="alert-dialog-slide-title" style={{paddingLeft: "80px", paddingRight: "80px"}}>
                    Authentication Information
                </DialogTitle>
                <DialogContent className="content" style={{paddingLeft: "80px", paddingRight: "80px", fontSize: "14px"}}>
                    <p>
                        NetApp Cloud Central Services use OAuth 2.0, an industry-standard protocol, for authorization. Communicating with an authenticated endpoint is a two step-process.
                    </p>
                    <p>
                        <ol>
                            <li>Acquire a JWT access token from the OAuth token endpoint.</li>
                            <li>Call an API endpoint with the JWT access token.</li>
                        </ol>
                    </p>
                    <span>
                        For purposes of using the execution feature of this API documentation, you may login using the <button className="ui-login" onClick={() => window.auth.loginRedirect({}, {service: "portal", startOnSignup: false})}>UI login screen</button>. This will automatically assign the relevant access token. If you wish, you can follow the instructions below and generate an access token via the API, then paste the JWT token in the corresponding box.
                        {window.authResult && <i style={{fontStyle: "italic"}}> Note: You are already logged in as <span style={{fontWeight: "bolder"}}>{window.authResult.idTokenPayload["http://cloud.netapp.com/user_metadata"].name}</span></i>}
                    </span>
                    <p>Acquiring an access token is different for federated and non-federated users.</p>
                    <div className="switch-tab">
                        <button disabled={this.state.authenticationDialog === "AUTHENTICATION"} onClick={() => this.setState({authenticationDialog: "AUTHENTICATION"})}>Regular Access</button>
                        <button disabled={this.state.authenticationDialog === "REFRESH-TOKEN"} onClick={() => this.setState({authenticationDialog: "REFRESH-TOKEN"})}>Federated Access</button>
                    </div>

                    {this.state.authenticationDialog === "AUTHENTICATION" &&  <div>
                        <h4>How to Acquire a JWT Access Token for non-federated users</h4>
                        <span>
                        <ul>
                            <li>Make an HTTP POST request to the endpoint <pre style={{display: "inline-block"}}>https://{window.__auth__.domain}/oauth/token</pre></li>
                            <li>Include the header <pre style={{display: "inline-block"}}>Content-Type: application/json</pre></li>
                            <li>Include the body:
                                <div style={{position: "relative"}}>
                                    <SyntaxHighlighter language='json'>{authBodyJsonText}</SyntaxHighlighter>
                                    <CopyToClipboard text={authBodyJsonText}><Button color="primary" style={{position: "absolute", top: 0, right: 0}}>Copy to clipboard</Button></CopyToClipboard>
                                </div>
                            </li>
                        </ul>
                    </span></div>}

                    {this.state.authenticationDialog === "REFRESH-TOKEN" && <div>
                        <h4>How to Acquire a JWT Access Token for federated users</h4>
                        <span>
                        <ul>
                            <li>Generate a long-lived refresh token from the <a href="/refresh-token">Refresh Token Generator</a></li>
                            <li>                        Make an HTTP POST request to the endpoint <pre style={{display: "inline-block"}}>https://{window.__auth__.domain}/oauth/token</pre></li>
                            <li>
                                Include the header: <pre style={{display: "inline-block"}}>Content-Type: application/json</pre>
                            </li>
                            <li>
                                Include the body:
                                <div style={{position: "relative"}}>
                                    <SyntaxHighlighter language='json'>{authBodyFederationJsonText}</SyntaxHighlighter>
                                    <CopyToClipboard text={authBodyFederationJsonText}><button className="primary" style={{position: "absolute", top: 0, right: 0}}>Copy to clipboard</button></CopyToClipboard>
                                </div>
                            </li>
                            <li>Extract the <pre style={{display: "inline-block"}}>access_token</pre> from the response</li>
                        </ul>
                        </span>
                    </div>}

                    <span>
                        The response of the API call to get an access token includes the field 'access_token'. After acquiring the access token, include the following header in all calls to an authenticated endpoint. <pre style={{display: "inline-block"}}>Authorization: Bearer YOUR_TOKEN</pre>
                    </span>

                    <h5>Use of the access token with this interactive API documentation</h5>
                    <TextField
                        label="Access Token"
                        InputLabelProps={{
                            shrink: true,
                        }}
                        placeholder="Paste your access token here for use with interactive API documentation"
                        fullWidth
                        margin="normal"
                        onChange={this.setAccessToken}
                    />
                </DialogContent>
                <DialogActions>
                    <Button onClick={this.handleCloseAuthenticationDialog} color="primary">
                        Close
                    </Button>
                </DialogActions>
            </Dialog>

            <div id="swagger-root"/>
        </div>
    }
}

ReactDOM.render(
    <App/>,
    document.getElementById('root'));