const _ = require('lodash');
const axios = require('axios');
const fs = require('fs');
const Promise = require('bluebird');

axios.defaults.baseURL = `https://${process.env.managementDomain}`;


const getClientMap = async (delay = 0) => {

    try {
        const {data: {access_token: accessToken}} = await axios.post("/oauth/token", {
            "grant_type": "client_credentials",
            "client_id": process.env.managementClientId,
            "client_secret": process.env.managementClientSecret,
            "audience": `https://${process.env.managementDomain}/api/v2/`
        });
        axios.defaults.headers.common['Authorization'] = `Bearer ${accessToken}`;
    }
    catch(err){
        console.log(`Failed to retrieve oath token for domain: ${process.env.managementDomain} with clientId: ${process.env.managementClientId}. Script exiting. No work done.`.red, err);
        process.exit(1);
    }

    console.log(`Attempting to get all auth0 clients.`);
    return getAllClientsRecursive([], 0, delay)
        .then(clientArr => {
            console.log(`Success. Got all ${clientArr.length} clients. Creating client map`);
            const nonOccm = _.filter(clientArr, client => !client.name.startsWith('Occm-Client'));
            const clientMap = _.reduce(nonOccm, (map, client) => {
                if(map[client.name]){
                    console.log(`Duplicate clients found with name: ${client.name}: id1: ${map[client.name]}, id2: ${client.client_id}`);
                    map[client.name] = map[client.name] + '   !!!!!    ' + client.client_id;
                }
                else {
                    map[client.name] = client.client_id;
                }
                return map
            }, {});
            fs.writeFileSync(`./../clients-map/${process.env.stage}-clients.json`, JSON.stringify(clientMap));

        }, err => {
            console.error(`Error. getting all clients failed`, err);
            throw err;
        })
};

const getAllClientsRecursive = (acc, lastPage, delay) => {
    const getAllClients = (page) => {
        return Promise.delay(delay).then(() => {
            console.log(`Getting auth0 clients ${page*100}-${(page+1)*100}...`);
            let paramsObject = {
                per_page: 100,
                page: page,
                include_totals: true,
                search_engine: 'v2',
                fields: 'client_id,name'
            };
            return axios.get('api/v2/clients', {
                params: paramsObject
            })
        })
    };

    const shouldDoAgain = (data) => data.start + data.limit < data.total;
    return getAllClients(lastPage)
        .then(({data}) => {
            const newAcc = acc.concat(data.clients);
            if (shouldDoAgain(data)) {
                return getAllClientsRecursive(newAcc, lastPage + 1, delay);
            } else {
                return newAcc;
            }
        })
};

getClientMap();