function fillProfile(user, context, callback) {
    var fullName;
    if (user.user_metadata && user.user_metadata.name) fullName = user.user_metadata.name;
    else if (user.given_name && user.family_name) fullName = user.given_name + " " + user.family_name;
    else if (user.name) fullName = user.name;
    else fullName = "unknown";

    var internalString = null;
    var isNetAppSaml = user.identities.find(identity => {
        return identity.connection === "NetAppSAML" || identity.connection === "TestSamlConn";
    });

    var profileIdentity = user.identities.find(identity => {
        return identity.profileData;
    });
    var netappEmployee = user.is_internal || (profileIdentity && profileIdentity.profileData && profileIdentity.profileData.is_internal);
    var isTestEmail = (user.email === 'testimio@netapp-test.com');

    if (user.email.startsWith("netapp-test") || user.email.startsWith("stagoccm") || user.email.endsWith("@test-netapp.com") || user.email.endsWith("@netapp-test.com")) internalString = "NetAppTest";
    if (user.email.endsWith("@ihcnetappu.com")) internalString = "NetAppCourse";
    if (user.email.startsWith("ptoccm") && user.email.endsWith("@gmail.com")) internalString = "NetAppTest";

    if ((isNetAppSaml && netappEmployee) || isTestEmail) internalString = "NetApp";
    if (user.email && user.email.toLowerCase().endsWith("@netapp.com") && user.email_verified) internalString = "NetApp";

    if (context.idToken) {
        delete context.idToken['picture'];
        context.idToken['http://cloud.netapp.com/user_metadata'] = Object.assign({
            email: user.email,
            name: fullName
        }, user.user_metadata);
        if (internalString) context.idToken['http://cloud.netapp.com/internal'] = internalString;
    }

    if (context.accessToken) {
        delete context.accessToken['picture'];
        context.accessToken['http://cloud.netapp.com/full_name'] = fullName;
        context.accessToken['http://cloud.netapp.com/email_verified'] = user.email_verified;
        if (internalString) context.accessToken['http://cloud.netapp.com/internal'] = internalString;
    }

    var requestedScopes = null;
    if (context.request && context.request.query) { //query for implicit grant
        requestedScopes = (context.request.query.scope || "").split(" ");
    } else if (context.request.body && context.request.body.scope) { //body for api grants
        requestedScopes = (context.request.body.scope || "").split(" ");
    }

    var defaultScopes = ['openid', 'profile', 'email']; //default if nothing is requested
    var allowedScopes = ['offline_access'];

    if (requestedScopes) {
        requestedScopes = requestedScopes.filter(function (scopeName) {
            return allowedScopes.indexOf(scopeName) !== -1 || defaultScopes.indexOf(scopeName) !== -1 ||
                (user.app_metadata && user.app_metadata[scopeName] === true) ||
                (scopeName === 'cc:netapp-internal' && internalString === 'NetApp')
        });
    }

    if (requestedScopes === null) {
        requestedScopes = defaultScopes;
    }

    if (requestedScopes.indexOf('profile') !== -1 && user.identities.length === 1 && user.identities[0].connection === 'Username-Password-Authentication') {
        requestedScopes.push('cc:update-password');
    }

    context.accessToken.scope = requestedScopes;

    callback(null, user, context);
}