const fs = require('fs');

//Rules code cannot be exported, so we import it as text:
const fillProfileCode = fs.readFileSync('./src/rules/Fill profile.js', 'utf8');
let fillProfileFunction = new Function("return " + fillProfileCode)();

let user, context, mockCallback;

const matchGrantedScopes = (expectedScopes) =>{
    expect(mockCallback.mock.calls[0][2]).toEqual({
        ...context,
        accessToken: expect.objectContaining({scope: expectedScopes})
    });
};

beforeEach(() => {
    user = {
        identities: [],
        email: 'user@lala.com'
    };
    context = {request: {}, accessToken: {}};
    mockCallback = jest.fn();
});

test('user that asks for unknown scope should not get it', () => {
    context.request.query = {scope: 'cc:new-scope'};

    fillProfileFunction(user, context, mockCallback);

    matchGrantedScopes([]);
});

test('user that asks for scope in the query and has it in his app_metadata should get it', () => {
    user.app_metadata = {
        'cc:my-scope': true
    };
    context.request.query = {scope: 'cc:my-scope'};

    fillProfileFunction(user, context, mockCallback);

    matchGrantedScopes(['cc:my-scope']);
});

test('user that asks for scope in the body and has it in his app_metadata should get it', () => {
    user.app_metadata = {
        'cc:my-scope': true
    };
    context.request.body = {scope: 'cc:my-scope'};

    fillProfileFunction(user, context, mockCallback);

    matchGrantedScopes(['cc:my-scope']);
});

test('user that asks for nothing should get default scopes', () => {
    fillProfileFunction(user, context, mockCallback);

    matchGrantedScopes(['openid', 'profile', 'email']);
});

test('username-password authenticated user that asks for profile should also get cc:update-password scope', () => {
    user.identities = [{connection: 'Username-Password-Authentication'}];

    fillProfileFunction(user, context, mockCallback);

    matchGrantedScopes(['openid', 'profile', 'email', 'cc:update-password']);
});

test('username-password authenticated user that has another identity method that asks for profile should NOT also get cc:update-password scope', () => {
    user.identities = [
        {connection: 'Username-Password-Authentication'},
        {connection: 'mySamlConnection'}
    ];

    fillProfileFunction(user, context, mockCallback);

    matchGrantedScopes(['openid', 'profile', 'email']);
});

test('if user asks for legit and non-legit scopes, should get only the legit', () => {
    user.app_metadata = {
        'cc:my-scope': true
    };
    context.request.query = {scope: 'cc:rule-the-world cc:my-scope'};

    fillProfileFunction(user, context, mockCallback);

    matchGrantedScopes(['cc:my-scope']);
});

test('only values with "true" value in app metadata are legit scopes', () => {
    user.app_metadata = {
        "occms": ["occmId1235467"],
        'cc:my-scope': true
    };
    context.request.query = {scope: 'occms cc:my-scope'};

    fillProfileFunction(user, context, mockCallback);

    matchGrantedScopes(['cc:my-scope']);
});

