function initialFederationLogin(user, context, callback) {
    const request = require('request@2.56.0');

    const isFederation = user.identities[0].provider !== "auth0";

    if(isFederation && !user.email){
        return callback(new Error('federation_no_email - Cannot login via federation without email address on account'));
    }

    const isNetapp = user.identities[0].connection === "TestSamlConn" || user.identities[0].connection === "NetAppSAML";

    if((!isFederation && !isNetapp) || (context.stats.loginsCount !== 1 && user.user_metadata && user.user_metadata.company)){
        return callback(null, user, context);
    }

    const userApiUrl = auth0.baseUrl + '/users';
    const userSearchApiUrl = auth0.baseUrl + '/users-by-email';
    const queryEmail = user.email.toLowerCase();
    const connectionName = context.connection;

    request({
            url: userSearchApiUrl,
            headers: {
                Authorization: 'Bearer ' + auth0.accessToken
            },
            qs: {
                email: queryEmail
            }
        },
        function(err, response, body) {
            if (err) return callback(err);
            if (response.statusCode !== 200) return callback(new Error(body));

            let data = JSON.parse(body);
            // Ignore current user, if present
            data = data.filter(function(u) {
                return (u.user_id !== user.user_id && u.identities.length === 1 && u.identities[0].connection === "Username-Password-Authentication");
            });

            if (data.length > 1) {
                return callback(new Error('[!] Rule: Multiple user profiles already exist - cannot select base profile to link with'));
            }
            if (data.length === 0) {
                console.log('[-] Skipping link rule & updating user_metadata with name and company');
                //add meta data
                let name = user.email;

                if(user.given_name && user.family_name) name = user.given_name + " " + user.family_name;
                else if(user.given_name) name = user.given_name;
                else if(user.family_name) name = user.family_name;

                let company = "Unknown";
                if(isNetapp) company = "NetApp";
                else if(isFederation) company = configuration[connectionName] || company;

                user.user_metadata = {
                    "name": name,
                    "company": company
                };
                auth0.users.updateUserMetadata(user.user_id, user.user_metadata);
                return callback(null, user, context);
            }

            const originalUser = data[0];
            const provider = user.identities[0].provider;
            const providerUserId = user.identities[0].user_id;

            console.log("[-] Linking user to existing account");

            request.post({
                url: userApiUrl + '/' + originalUser.user_id + '/identities',
                headers: {
                    Authorization: 'Bearer ' + auth0.accessToken
                },
                json: { provider: provider, user_id: providerUserId }
            }, function(err, response) {
                if (response && response.statusCode >= 400) {
                    return callback(new Error('Error linking account: ' + response.statusMessage));
                }
                context.primaryUser = originalUser.user_id;

                return callback(null, originalUser, context);
            });
        });
}