const entry = require("./analytics-apis");

const analyticsKey = "b5c35b09-552b-4b30-bbbc-1b07a7971d27";
const { ForbiddenError } = require("./errors");

describe("splitName", () => {
    it("should not fail when given an empty string", () => {
        const result = entry.splitName("");
        return expect(result).toEqual({ firstname: "", lastname: "" });
    });

    it("should have only first name", () => {
        const result = entry.splitName("FirstName");
        return expect(result).toEqual({ firstname: "FirstName", lastname: "" });
    });

    it("should have both a first and last name", () => {
        const result = entry.splitName("First Last");
        return expect(result).toEqual({ firstname: "First", lastname: "Last" });
    });

    it("should have both a first and last name, where the first contains the middle as well", () => {
        const result = entry.splitName("First M Last");
        return expect(result).toEqual({ firstname: "First M", lastname: "Last" });
    });
});


describe("createHubspotProperties", () => {
    it("should return a correctly formatted hubspot properties object from input JSON", () => {
        const inputJSON = {
            email: 'user@mail.com',
            firstname: 'first',
            lastname: 'last',
            company: 'company',
            auth0_user_id: 'id',
            portal_email_validated: 'No',
            portal_last_login_date: 'last login date',
            portal_number_of_logins: '5',
            portal_signups_origin: 'Portal',
            portal_signup_date: 'sign up date'
        };

        const result = entry.createHubspotProperties(inputJSON);
        return expect(result).toEqual([
            {
                property: 'email',
                value: 'user@mail.com'
            },
            {
                property: 'firstname',
                value: 'first'
            },
            {
                property: 'lastname',
                value: 'last'
            },
            {
                property: 'company',
                value: 'company'
            },
            {
                property: 'auth0_user_id',
                value: 'id'
            },
            {
                property: 'portal_email_validated',
                value: 'No'
            },
            {
                property: 'portal_last_login_date',
                value: 'last login date'
            },
            {
                property: 'portal_number_of_logins',
                value: '5'
            },
            {
                property: 'portal_signups_origin',
                value: 'Portal'
            },
            {
                property: 'portal_signup_date',
                value: 'sign up date'
            }]);
    });
});


describe("userLoginSignUp", () => {
    it("should return a forbidden error if the correct key is not passed", () => {
        const user = {
            email: "garbage_user@netapp.com"
        };
        const context = {};
        const promise = entry.userLoginSignUp({
            user, context, eventType: 'login', analyticsKey: "wrong"
        });
        return expect(promise).rejects.toEqual(new ForbiddenError());
    });

    it("should not create a hubspot user for 'garbage' users", () => {
        const user = {
            email: "garbage_user@netapp.com"
        };
        const context = {};
        const promise = entry.userLoginSignUp({
            user, context, eventType: 'login', analyticsKey
        });
        return expect(promise).resolves.toEqual();
    });
});
