const nock = require('nock');

const entry = require("./portal-apis");
const { authAccount } = require("./auth-utils");

const nockBase = nock(`https://${authAccount.domain}`);
// const nodemailerMock = require('nodemailer-mock');

beforeEach(() => {
    nockBase
        .post('/oauth/token')
        .reply(200, { access_token: "mock-access-token" });
});


describe("update-user-info", () => {
    it("should update the given user's information", () => {
        nockBase
            .patch("/api/v2/users/user-1", {
                user_metadata: { name: "user-name" }
            })
            .reply(204);

        const promise = entry.updateUserInfo(({ userName: "user-name", userId: "user-1" }));

        return expect(promise).resolves.toEqual(null);
    });
});

describe("user-id-by-email", () => {
    it("should return the id for existent user", () => {
        nockBase
            .get("/api/v2/users")
            .query({ q: 'email:"user@email.com"', search_engine: 'v3' })
            .reply(200, [{ user_id: 'userId1' }]);

        const promise = entry.getUserIdByEmail({ email: 'user@email.com' });

        return expect(promise).resolves.toEqual({ userId: 'userId1' });
    });

    it("should throw error for non-existent user", () => {
        nockBase
            .get("/api/v2/users")
            .query({ q: 'email:"non-existent@email.com"', search_engine: 'v3' })
            .reply(200, []);

        const promise = entry.getUserIdByEmail({ email: 'non-existent@email.com' });

        return expect(promise).rejects.toHaveProperty("message", 'No user has the given email address: non-existent@email.com');
    });
});

describe("does-user-exist", () => {
    it("should return true for existent user", () => {
        nockBase
            .get("/api/v2/users")
            .query({ q: 'email:"user@email.com"', search_engine: 'v3' })
            .reply(200, [{ user_id: 'userId1' }]);

        const promise = entry.doesUserExist({ email: 'user@email.com' });

        return expect(promise).resolves.toEqual({ doesExist: true });
    });

    it("should throw error for non-existent user", () => {
        nockBase
            .get("/api/v2/users")
            .query({ q: 'email:"non-existent@email.com"', search_engine: 'v3' })
            .reply(200, []);

        const promise = entry.doesUserExist({ email: 'non-existent@email.com' });

        return expect(promise).resolves.toEqual({ doesExist: false });
    });
});
