const _ = require('lodash');
const AWS = require('aws-sdk');

AWS.config.update({ region: 'us-east-1' });
AWS.config.setPromisesDependency(null);
const dynamoDb = new AWS.DynamoDB.DocumentClient();

const eventMatcher = event => {
    console.log(event);
    switch (event.type) {
        case "USER-HAS-S3-TIERING": {
            const userId = _.get(event, "context.authId");
            if (!userId) {
                return Promise.reject(new Error('No context.authId present for USER-HAS-S3-TIERING event'));
            }

            const params = {
                TableName: process.env.userInfoTable,
                Key: {
                    userId
                },
                UpdateExpression: "set isOCCMS3Tiering = :val",
                ExpressionAttributeValues: {
                    ":val": true
                }
            };

            return dynamoDb.update(params).promise().catch(err => {
                console.log("Failed updating isOCCMS3Tiering flag in dynamodb");
                console.log(err);
                throw new Error("Failed updating USER-HAS-S3-TIERING event in database");
            });
        }
        default:
            return Promise.reject(event.type ? new Error(`No match for event type ${event.type}`) : "No event type specified.");
    }
};

const eventsMatcher = events => Promise.all(events.map(eventMatcher));

exports.handler = (event, context, callback) => {
    console.log("Received push event from Cloud Manager");
    console.log(event);

    let events;

    if (!_.isArray(event)) {
        events = [event];
    } else { events = event; }

    eventsMatcher(events).then(response => callback(null, response), err => callback(err));
};

const yarger = require("yargs") // eslint-disable-line no-unused-vars, import/order
    .command("test", "test", yargs => {
        yargs.demandOption(["userId", "type"]);
    }, argv => {
        process.env.userInfoTable = "portal-backend-dev-userInfo";
        eventsMatcher([{ context: { authId: argv.userId }, type: argv.type }]);
    }).argv;
