const pusher = require("./log-stream-pusher");

const audit = {
    type: "AUDIT-CLOSE",
    timestamp: 1522066314923,
    auditContext: {
        internalUserFlag: "NetApp",
        pattern: "/occm/list-occms",
        method: "GET",
        requestId: "dedbda96-30ee-11e8-849d-9f5354dc7e9c",
        referer: "https://dev.services.cloud.netapp.com/",
        requestData: {
            body: null, queryParams: null, principalId: "PrincipAkumal", urlParams: {}, scopes: ["openid", "profile"]
        }
    },
    data: { statusCode: 500, body: { message: "This is an exception" }, status: "FAILED" }
};

describe("handleAudit", () => {
    it("should properly prefix all fields", () => {
        const result = pusher.handleAudit(audit);
        return expect(result[1]).toEqual({
            auditContext: {
                internalUserFlag: "NetApp",
                method: "GET",
                pattern: "/occm/list-occms",
                referer: "https://dev.services.cloud.netapp.com/",
                requestData: {
                    body: null,
                    principalId: "PrincipAkumal",
                    queryParams: null,
                    scopes: ["openid", "profile"],
                    urlParams: {}
                },
                requestId: "dedbda96-30ee-11e8-849d-9f5354dc7e9c"
            },
            data: {
                body: {
                    s_message: "This is an exception"
                },
                status: "FAILED",
                statusCode: 500
            },

            date: "2018-03-26T15:11:54+03:00",
            timestamp: 1522066314923,
            type: "AUDIT-CLOSE"
        });
    });

    it('should handle mixed types', () => {
        const mixedAudit = {
            type: "AUDIT-CLOSE",
            timestamp: 1522066314923,
            auditContext: {
                internalUserFlag: "NetApp",
                pattern: "/occm/list-occms",
                method: "GET",
                requestId: "dedbda96-30ee-11e8-849d-9f5354dc7e9c",
                referer: "https://dev.services.cloud.netapp.com/",
                requestData: {
                    body: null,
                    queryParams: null,
                    principalId: "PrincipAkumal",
                    urlParams: {},
                    scopes: ["openid", "profile"]
                }
            },
            data: { statusCode: 500, body: { things: [123, 'Lemonade', { I: 'am an object' }] }, status: "FAILED" }
        };

        const result = pusher.handleAudit(mixedAudit);
        return expect(result[1]).toEqual({
            auditContext: {
                internalUserFlag: "NetApp",
                method: "GET",
                pattern: "/occm/list-occms",
                referer: "https://dev.services.cloud.netapp.com/",
                requestData: {
                    body: null,
                    principalId: "PrincipAkumal",
                    queryParams: null,
                    scopes: ["openid", "profile"],
                    urlParams: {}
                },
                requestId: "dedbda96-30ee-11e8-849d-9f5354dc7e9c"
            },
            data: {
                body: {
                    a_o_things: [
                        { _wrapped_s: "123" },
                        { _wrapped_s: "'Lemonade'" },
                        { _wrapped_s: "{ I: 'am an object' }" }
                    ]

                },
                status: "FAILED",
                statusCode: 500
            },

            date: "2018-03-26T15:11:54+03:00",
            timestamp: 1522066314923,
            type: "AUDIT-CLOSE"
        });
    });
});

const noParseRecord = {
    eventSource: "aws:kinesis",
    kinesis: {
        kinesisSchemaVersion: '1.0',
        partitionKey: '899aeb5e0b0129aa8fdea5ac51967648',
        sequenceNumber: '49581229900566828945658533047933084726976202088615247874',
        data: 'this cant be parsed',
        approximateArrivalTimestamp: 1522231724.419
    }
};

const auditRecord = {
    eventSource: "aws:kinesis",
    kinesis: {
        kinesisSchemaVersion: '1.0',
        partitionKey: '78c67758-a2e7-4845-a24d-a89d1145e50d',
        sequenceNumber: '49581229900566828945658533043872302898890641044142030850',
        data: 'eyJ0eXBlIjoiQVVUSC1SQVRFIiwidGltZXN0YW1wIjoxNTIyMjMxNDEwMjQ2LCJkYXRhIjp7IngtcmF0ZWxpbWl0LWxpbWl0IjoiMzAiLCJ4LXJhdGVsaW1pdC1yZW1haW5pbmciOiIyOSIsIngtcmF0ZWxpbWl0LXJlc2V0IjoiMTUyMjIzMTQxMSIsInVybCI6Imh0dHBzOi8vZGV2LW5ldGFwcC1jbG91ZC1hY2NvdW50LmF1dGgwLmNvbS9vYXV0aC90b2tlbiJ9fQ==',
        approximateArrivalTimestamp: 1522231410.256
    }
};

describe("formatRecords", () => {
    it("should properly flatten the response array even if empty", () => {
        const result = pusher.formatRecords([noParseRecord]);
        return expect(result).resolves.toEqual([]);
    });

    it("should properly construct a formatted array for elastic entry", () => {
        const promise = pusher.formatRecords([auditRecord]);
        return promise.then(result => {
            expect(result[0].create._index).toEqual("rate-auth-undefined-");
            expect(result[0].create._type).toEqual("rate");
            expect(result[1].type).toEqual("AUTH-RATE");
        });
    });
});

const logMessages = {
    messageType: 'DATA_MESSAGE',
    owner: '055518636490',
    logGroup: '/aws/lambda/portal-backend-dev-logs-auth0',
    logStream: '2018/03/28/[$LATEST]3444f236765a4aa39b31c989268eaf07',
    subscriptionFilters: ['kinesisFilter'],
    logEvents: [
        {
            id: '33946934931400671278636867391734612561877169658896318464',
            timestamp: 1522233209213,
            message: '2018-03-28T10:33:29.213Z\t73707e04-3273-11e8-a86a-237a6faebf10\tAttempting to push Auth0 logs to Elastic Search'
        },
        {
            id: '33946934931422972023835398014876148280149818020402298881',
            timestamp: 1522233209214,
            message: '2018-03-28T10:33:29.213Z\t73707e04-3273-11e8-a86a-237a6faebf10\tGetting auth0 checkpoint from dynamo\n'
        },
        {
            id: '33946934931422972023835398014876148280149818020402298882',
            timestamp: 1522233209214,
            message: 'START RequestId: a631dc08-22d5-4d89-8390-37b1461be99b Version: $LATEST'
        },
        {
            id: '33946934931422972023835398014876148280149818020402298883',
            timestamp: 1522233209214,
            message: 'END RequestId: f79c8b72-376d-4f6b-b573-85656c664004'
        },
        {
            id: '33946934931422972023835398014876148280149818020402298884',
            timestamp: 1522233209214,
            message: 'REPORT RequestId: f79c8b72-376d-4f6b-b573-85656c664004\tDuration: 9.99 ms Billed Duration: 100 ms Memory Size: 1024 MB\tMax Memory Used: 39 MB'
        }
    ]
};

describe("handleLogMessages", () => {
    it("should generate the proper es bulk array for many log entries", () => {
        const result = pusher.handleLogMessages(logMessages);
        return expect(result).toEqual([
            { create: { _id: "33946934931400671278636867391734612561877169658896318464", _index: "log-undefined-2018.3.28", _type: "log" } },
            {
                date: "2018-03-28T13:33:29+03:00", timestamp: 1522233209213, message: "Attempting to push Auth0 logs to Elastic Search", logGroup: "dev-logs-auth0", requestId: "73707e04-3273-11e8-a86a-237a6faebf10"
            },
            { create: { _id: "33946934931422972023835398014876148280149818020402298881", _index: "log-undefined-2018.3.28", _type: "log" } },
            {
                date: "2018-03-28T13:33:29+03:00", logGroup: "dev-logs-auth0", message: "Getting auth0 checkpoint from dynamo", requestId: "73707e04-3273-11e8-a86a-237a6faebf10", timestamp: 1522233209214
            },
            { create: { _id: "33946934931422972023835398014876148280149818020402298882", _index: "log-undefined-2018.3.28", _type: "log" } },
            {
                date: "2018-03-28T13:33:29+03:00", logGroup: "dev-logs-auth0", message: "START", requestId: "a631dc08-22d5-4d89-8390-37b1461be99b", timestamp: 1522233209214
            },
            { create: { _id: "33946934931422972023835398014876148280149818020402298883", _index: "log-undefined-2018.3.28", _type: "log" } },
            {
                date: "2018-03-28T13:33:29+03:00", logGroup: "dev-logs-auth0", message: "END", requestId: "f79c8b72-376d-4f6b-b573-85656c664004", timestamp: 1522233209214
            },
            { create: { _id: "33946934931422972023835398014876148280149818020402298884", _index: "log-undefined-2018.3.28", _type: "log" } },
            {
                date: "2018-03-28T13:33:29+03:00", logGroup: "dev-logs-auth0", message: "REPORT", requestId: "f79c8b72-376d-4f6b-b573-85656c664004", timestamp: 1522233209214
            }
        ]);
    });
});
