const axios = require('axios');
const bodybuilder = require('bodybuilder');
const program = require("commander");
const { sendInternalEmail } = require('./../utils/internal-email');
const { internalGalOnly } = require("./../consts");
const { refreshToken } = require("./getToken");

const KIBANA_URL = process.env.KIBANA_PROXY_URL;
const ENDPOINT = `path=auth-${process.env.stage}-*%2F_search&method=POST`;

program
    .description("Run the script with acess and secret key to generate and download daily_business_usage_by_instance_type reports from AWS.")
    .option("-c, --client-id [client-id]", "Auth0 client-id")
    .option("-t, --refresh-token [refresh-token]", "Auth0 refresh-token")
    .parse(process.argv);

const authTextEmpty = () => bodybuilder()
    .query('match_phrase', 'auth_type_text', '')
    .query('range', 'date', { gte: "now-7d/d" })
    .build();

const authTextMissing = () => bodybuilder()
    .notQuery('exists', 'auth_type_text')
    .query('range', 'date', { gte: "now-7d/d" })
    .build();

const getEmptyAuthText = async () => {
    const emptyQuery = await authTextEmpty();
    const missingQuery = await authTextMissing();
    const cookie = await refreshToken(program.clientId, program.refreshToken, false);
    await axios.request({
        url: `${KIBANA_URL}?${ENDPOINT}`,
        method: "post",
        headers: {
            "content-type": "application/json",
            cookie,
            "kbn-version": "6.1.1",
            withCredentials: true
        },
        data: emptyQuery
    })
        .then(res => res.data.hits.total)
        .then(total => {
            console.log(`There are ${total} records with an empty value for auth_type_text`);
            if (total > 0) {
                sendInternalEmail("Unrecognized Auth0 Log", `An unrecognized Auth0 log type has been entered in to the ${process.env.stage} Kibana`, internalGalOnly);
            }
        })
        .catch(err => console.log(err));
    await axios.request({
        url: `${KIBANA_URL}?${ENDPOINT}`,
        method: "post",
        headers: {
            "content-type": "application/json",
            cookie,
            "kbn-version": "6.1.1",
            withCredentials: true
        },
        data: missingQuery
    })
        .then(res => res.data.hits.total)
        .then(total => {
            console.log(`There are ${total} records with missing the for auth_type_text field`);
            if (total > 0) {
                sendInternalEmail("Unrecognized Auth0 Log", `An unrecognized Auth0 log type has been entered in to the ${process.env.stage} Kibana`, internalGalOnly);
            }
        })
        .catch(err => console.log(err));
};

getEmptyAuthText();
