const axios = require('axios');
const fs = require('fs-extra');
const moment = require('moment');

const AUTH0_ENDPOINT = "https://netapp-cloud-account.auth0.com/oauth/token";
const FILE_PATH = './src/schedules/token.json';

const writeJSON = (path, json, time) => {
    json.time = time;
    fs.ensureFileSync(path);
    fs.writeFileSync(path, JSON.stringify(json));
    return json;
};

module.exports.refreshToken = async (clientId, refreshToken, forceRefresh) => {
    const token = fs.readJsonSync(FILE_PATH);
    const now = Number(moment().format('x'));
    // If current token hasn't expired yet, return it
    if (((token.time + (token.expires_in * 1000)) - 5000 > now) && !forceRefresh) {
        writeJSON(FILE_PATH, token, token.time);
        return `AuthorizationCookie=${token.access_token}`;
    }
    // Otherwise, get a new one
    return axios({
        method: 'post',
        url: AUTH0_ENDPOINT,
        headers: {
            'content-type': 'application/json'
        },
        data: {
            grant_type: 'refresh_token',
            client_id: clientId,
            refresh_token: refreshToken
        }
    })
        .then(res => writeJSON(FILE_PATH, res.data, Number(moment().format('x'))))
        .then(data => `AuthorizationCookie=${data.access_token}`)
        .catch(err => console.log(err));
};
