import React from 'react';
import { storiesOf } from '@storybook/react';

//From here: https://stackoverflow.com/questions/5623838/rgb-to-hex-and-hex-to-rgb
const hexToRgb = (hex) => {
    const result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
    return result ? [
        parseInt(result[1], 16), //r
        parseInt(result[2], 16), //g
        parseInt(result[3], 16)  //b
    ] : null;
};

// Based on this: https://stackoverflow.com/questions/3942878/how-to-decide-font-color-in-white-or-black-depending-on-background-color
const getColorLuminance = ([r, g, b]) => {
    [r, g, b] = [r, g, b].map(c => {
        c /= 255.0;
        if (c <= 0.03928) {
            return c / 12.92
        } else {
            return Math.pow((c + 0.055) / 1.055, 2.4);
        }
    });

    return 0.2126 * r + 0.7152 * g + 0.0722 * b;
};

const getContrastColor = (hex) => getColorLuminance(hexToRgb(hex)) > 0.179 ? '#000000' : '#ffffff';

const getColorDiv = (colorName, hex) => {
    return <div key={colorName}
                style={{ backgroundColor: `${hex}`, color: getContrastColor(hex), padding: 15, margin: 2 }}>
        {colorName}
        <div style={{ float: 'right' }}>{hex.toUpperCase()}</div>
    </div>
};

const appColors = [
    { name: 'primary-blue', hex: '#3d84ff' },
    { name: 'secondary-blue', hex: '#003eae' },
    { name: 'lochmara-blue', hex: '#2c5e9c' },
    { name: 'mariner-blue', hex: '#2B67C5' },
    { name: 'link-water-blue', hex: '#e8f2f8' },
    { name: 'white-background', hex: '#fbfbfb' },
    { name: 'grey-background', hex: '#f5f5f5' },
    { name: 'light-grey', hex: '#d7d7d7' },
    { name: 'grey-5', hex: '#6c6f78' },
    { name: 'grey-6', hex: '#434957' },
    { name: 'text-dark-grey', hex: '#636363' },
    { name: 'text-error', hex: '#ca3652' }
];
const productCategoriesColors = [
    { name: 'category-storage', hex: '#5933b4' },
    { name: 'category-services', hex: '#1ca6ff' },
    { name: 'category-controls', hex: '#cc3cd6' },
    { name: 'category-analytics', hex: '#E9A200' }
];

const productCategoriesSecondaryColors = [
    { name: 'category-storage-secondary', hex: '#e2ddef' },
    { name: 'category-services-secondary', hex: '#d3e7f4' },
    { name: 'category-storage-controls', hex: '#fde6ff' },
    { name: 'category-services-analytics', hex: '#ffe6d2' }
];

storiesOf('Colors', module)
    .add('Colors', () => (
        <div style={{ width: 1135, margin: 'auto' }}>
            <h4>App colors</h4>
            {appColors.map(({ name, hex }) => getColorDiv(name, hex))}
            <h4>Product categories colors</h4>
            {productCategoriesColors.map(({ name, hex }) => getColorDiv(name, hex))}
            <h4>Product categories secondary colors</h4>
            {productCategoriesSecondaryColors.map(({ name, hex }) => getColorDiv(name, hex))}
        </div>
    ));