import React from 'react';
import { storiesOf } from '@storybook/react';
import { MemoryRouter } from 'react-router';
import buttons from '../../ui-components/src/button/button.module.scss';
import dialogs from "../../ui-components/src/dialog/dialog.module.scss";
import styles from './components.module.scss';
import { FormFieldInput } from "ui-components";
import { ReactComponent as InlineLoader } from "ui-components/src/images/loaders/inline-loader.svg";

const ButtonView = (props = { children, title }) => (
    <div className={styles.item}>
        <p className={styles.title}>{props.title}</p>
        {props.children}
    </div>
);

storiesOf('Components', module)
    .addDecorator(story => (
        <MemoryRouter initialEntries={['/']}>{story()}</MemoryRouter>
    ))
    .add('Buttons and Dialogs', () => (
        <div className={styles.wrapper}>
            <ButtonView title="Regular">
                <button className={buttons.primary}>Idle</button>
            </ButtonView>
            <ButtonView title="Regular Disabled">
                <button className={buttons.primary} disabled={true}>Disabled</button>
            </ButtonView>
            <ButtonView title="Cancel">
                <button className={buttons.cancel}>Cancel</button>
            </ButtonView>
            <ButtonView title="Dangerous Action">
                <button className={buttons.dangerous}>Danger</button>
            </ButtonView>
        </div>
    ))
    .add('Dialogs', () => (
        <div style={{
            display: "flex",
            flexDirection: "column",
            width: "400px",
            border: "2px solid black",
            padding: "20px"
        }}>
            <p className={styles.title}>Button Pair for Dialogs</p>
            <div className={dialogs["button-pair-wrapper"]}>
                <button className={buttons.primary}>Idle</button>
                <button className={buttons.cancel}>Cancel</button>
            </div>
        </div>
    ))
    .add('Inline Loader', () => (
        <div>
            <InlineLoader className="inline-loader"/>
        </div>
    ))
    .add('Loading Mask', () => (
        <div>
            <div className={styles['loading-mask']}/>
        </div>
    ))
    .add('Input', () => (
        <div className={styles["input-wrapper"]}>
            <FormFieldInput label="Empty" type="text" placeholder="placeholder text" autoFocus={true}/>
            <FormFieldInput label="With Value" type="text" value="User text"/>
            <FormFieldInput label="Pending" type="text" value="Think about that" pending={true} InlineLoaderIcon={InlineLoader}/>
            <FormFieldInput label="With Error" type="text" value="Wrong value" errorMessage="Something is wrong."/>
            <FormFieldInput label="Another one" type="text"/>
        </div>
    ))
    .add('Select', () => (
        <div>TBD</div>
    ));