const _ = require("lodash");

// FYI testLinkAndCollect was not separated to 2 functions (one for verifying link and another to collect hrefs) to not affect performance by navigating to the same URL twice in the browser
const testLinkAndCollect = async (browser, rootHref, collect) => {

    const whiteList = [
        'cloud.netapp.com',
        'services.cloud.netapp.com'
    ];

    const result = {
        rootLink: rootHref, // {url, parentUrl}
        hrefs: [],
        isBroken: false,
        isStaging: false,
        isPuppeteerError: false
    };

    // check if URL accidentally directing to staging
    if(rootHref.url.includes('staging') || rootHref.url.includes('sandbox')) {
        result.isStaging = true;
        return result;
    }

    // check if URL is broken and collect all hrefs in page
    const page = await browser.newPage();
    try {
        const response = await page.goto(rootHref.url, {"waitUntil": "networkidle2"});
        const responseStatus = await response.status();
        console.log(`Navigation URL: ${rootHref.url} Navigation status: ${responseStatus}`);
        // in case of redirect from original link, verify that the redirect url is not leading to production
        const url = await page.url();
        if(url.includes('staging') || url.includes('sandbox')) {
            result.isStaging = true;
            return result;
        }
        if(responseStatus >= 400){
            result.isBroken = true;
            return result;
        }
        if(collect && whiteList.reduce((isWhiteListed, whiteListUrl) => isWhiteListed || _.includes(rootHref.url, whiteListUrl), false)) {
            await page.waitFor(2000);
            result.hrefs = await page.$$eval('a', as => as.map(a => a.href));
            result.hrefs = result.hrefs.map(href => {
                return {url: href, parentUrl: rootHref.url};
            })
        }
        await page.close();
    } catch (e) {
        console.log(`ERROR: ${e}`);
        result.isPuppeteerError = true;
        return result;
    }

    return result;
};

exports.testLinkAndCollect = testLinkAndCollect;