const chai = require("chai");
const expect = require('chai').expect;
const Constants = require('../Constants');
const Initializer = require('../specInitializer');
const Promise = require('bluebird');
const jwtDecoder = require('../general-utils').decodeToken;
const _ = require('lodash');
const chaiAsPromised = require("chai-as-promised");
chai.use(chaiAsPromised);

const { logger, clients } = Initializer('OCCM Integration Spec');

describe('DynamodbClient spec Spec - updateUserDevelopmentClients', function() {
    it('Should change user\' static clients access permissions in dynamo', async function() {
        await clients.dynamodbClient.updateUserDevelopmentClients(Constants.defaultUserAuth0Sub, []);
        let userInfoDynamo = await clients.dynamodbClient.getUserInfo(Constants.defaultUserAuth0Sub);
        logger.debug(`User info from dynamo: ${JSON.stringify(userInfoDynamo)}`);
        expect(userInfoDynamo.Item.developmentClients).to.equal(undefined);

        await clients.dynamodbClient.updateUserDevelopmentClients(Constants.defaultUserAuth0Sub, ['some-client-id']);
        userInfoDynamo = await clients.dynamodbClient.getUserInfo(Constants.defaultUserAuth0Sub);
        logger.debug(`User info from dynamo: ${JSON.stringify(userInfoDynamo)}`);
        expect(userInfoDynamo.Item.developmentClients.values).to.eql(['some-client-id']);
        await clients.dynamodbClient.updateUserDevelopmentClients(Constants.defaultUserAuth0Sub, []);
    });
});

describe('DynamodbClient spec Spec - updateSubordinateUsers', function() {
    it('Should change user\' static clients access permissions in dynamo', async function() {
        await clients.dynamodbClient.updateSubordinateUsers(Constants.defaultUserAuth0Sub, []);
        let userInfoDynamo = await clients.dynamodbClient.getUserInfo(Constants.defaultUserAuth0Sub);
        logger.debug(`User info from dynamo: ${JSON.stringify(userInfoDynamo)}`);
        expect(userInfoDynamo.Item.subordinateUsers).to.equal(undefined);

        await clients.dynamodbClient.updateSubordinateUsers(Constants.defaultUserAuth0Sub, ['some-user-id']);
        userInfoDynamo = await clients.dynamodbClient.getUserInfo(Constants.defaultUserAuth0Sub);
        logger.debug(`User info from dynamo: ${JSON.stringify(userInfoDynamo)}`);
        expect(userInfoDynamo.Item.subordinateUsers.values).to.eql(['some-user-id']);
        await clients.dynamodbClient.updateSubordinateUsers(Constants.defaultUserAuth0Sub, []);
    });
});