const TestLogger = require('../logger/TestLogger');
const logger = new TestLogger("Axios handler");

exports.resolvedResponseInterceptor = (response) => {
    return response.data || response.status;
};

exports.rejectedResponseInterceptor = (error) => {
    let errorString = '\n';
    if (error.response) {
        // The request was made and the server responded with a status code
        // that falls out of the range of 2xx
        errorString += `DATA: ${JSON.stringify(error.response.data)}\nSTATUS: ${JSON.stringify(error.response.status)} \nHEADERS: ${JSON.stringify(error.response.headers)} \n`;
    } else if (error.request) {
        // The request was made but no response was received
        // `error.request` is an instance of XMLHttpRequest in the browser and an instance of
        // http.ClientRequest in node.js
        errorString += `REQUEST: ${JSON.stringify(error.request)}\n`;
    } else {
        // Something happened in setting up the request that triggered an Error
        errorString += `MESSAGE: ${JSON.stringify(error.message)}\n`;
    }
    errorString += `CONFIG: ${JSON.stringify(error.config)}\n`;
    logger.error(errorString);
    return Promise.reject(error);
};

exports.resolvedRequestInterceptor = (config) => {
    logger.info(`Request URL: ${config.baseURL}${config.url}`);
    return config;
};

exports.rejectedRequestInterceptor = (error) => {
    logger.error(error);
    return Promise.reject(error);
};


