const expect = require('chai').expect;
const Constants = require('../Constants');
const Auth0Client = require('../auth0/Auth0Client');
const CloudCentralClient = require('./CloudCentralClient');
const TestLogger = require('../../logger/TestLogger');
const chai = require("chai");
const chaiAsPromised = require("chai-as-promised");
chai.use(chaiAsPromised);

const logger = new TestLogger("Auth0Client-spec");
const auth0Client = new Auth0Client(logger);
const cloudCentralClient = new CloudCentralClient(logger);

describe('CloudCentralClient getCustomerSuccessStories', async function() {
    it('Sanity', async function() {
        const userToken = await auth0Client.getCloudCentralUserToken(Constants.testimioUserEmail, Constants.testimioUserPassword);
        const response = await cloudCentralClient.getCustomerSuccessStories(userToken);
        // noinspection BadExpressionStatementJS
        expect(response).to.not.be.empty;
        expect(response.includes('Company,Vertical,Region,Country,Use Case,Product,Cloud Provider,Public Reference,LinkName1,LinkUrl1,LinkName2,LinkUrl2,LinkName3,LinkUrl3,LinkName4,LinkUrl4,LinkName5,LinkUrl5,LinkName6,LinkUrl6,LinkName7,LinkUrl7,LinkName8,LinkUrl8,LinkName9,LinkUrl9')).to.equal(true);
    });

    it('Error', async function() {
        const userToken = await auth0Client.getCloudCentralUserToken(Constants.defaultTestUserEmail, Constants.defaultTestUserPassword);
        const promise = cloudCentralClient.getCustomerSuccessStories(userToken);
        return expect(promise)
            .to.eventually.be.rejected
            .and.be.an.instanceOf(Error)
            .then(error => {
                expect(error.response.data.message).to.equal('Forbidden');
                expect(error.response.status).to.equal(403);
            })
    });
});

describe('CloudCentralClient getCustomerSuccessStories', async function() {
    it('Sanity', async function() {
        const userToken = await auth0Client.getCloudCentralUserToken(Constants.testimioUserEmail, Constants.testimioUserPassword);
        const file = await cloudCentralClient.getCustomerSuccessStories(userToken);
        const response = await cloudCentralClient.uploadCustomerSuccessStories(userToken, file);
        // noinspection BadExpressionStatementJS
        expect(response).to.equal(204);
    });

    it('Error', async function() {
        const userToken = await auth0Client.getCloudCentralUserToken(Constants.defaultTestUserEmail, Constants.defaultTestUserPassword);
        const promise = cloudCentralClient.uploadCustomerSuccessStories(userToken, 'Company,Vertical,Region,Country,Use Case,Product,Cloud Provider,Public Reference,LinkName1,LinkUrl1,LinkName2,LinkUrl2,LinkName3,LinkUrl3,LinkName4,LinkUrl4,LinkName5,LinkUrl5,LinkName6,LinkUrl6,LinkName7,LinkUrl7,LinkName8,LinkUrl8,LinkName9,LinkUrl9');
        return expect(promise)
            .to.eventually.be.rejected
            .and.be.an.instanceOf(Error)
            .then(error => {
                expect(error.response.data.message).to.equal('Forbidden');
                expect(error.response.status).to.equal(403);
            })
    });
});