import React from 'react';
import { connect } from 'react-redux';
import _ from 'lodash';

import { ReactComponent as UserIcon } from "ui-components/src/images/monochrome-icons/ic-user.svg";
import buttons from "ui-components/src/button/button.module.scss";

class ManageUserWorkspacesOverlay extends React.Component {
    constructor(props) {
        super(props);

        this.state = {
            associatedWorkspaces: this.props.userForWorkspacesManagement.workspaces.map(workspace => _.extend({}, workspace, { checked: true })),
            unAssociatedWorkspaces: _.differenceWith(this.props.accountWorkspaces, this.props.userForWorkspacesManagement.workspaces, _.isEqual),
            changedDone: false
        };
    }

    updateChangesDone() {
        this.setState({
            changesDone: _.some(this.state.associatedWorkspaces, workspace => !workspace.checked) ||
                _.some(this.state.unAssociatedWorkspaces, workspace => workspace.checked)
        })
    }

    handleCheckboxChange = (workspacesGroup, workspacePublicId) => {
        this.setState(prevState => ({
            [workspacesGroup]: prevState[workspacesGroup].map(workspace => {
                if (workspace.workspacePublicId === workspacePublicId) workspace.checked = !workspace.checked;
                return workspace;
            })
        }), this.updateChangesDone);
    };

    submitButtonClicked() {
        const workspaceIdsToRemove = _(this.state.associatedWorkspaces).reject('checked').map('workspacePublicId').value();
        const workspaceIdsToAdd = _(this.state.unAssociatedWorkspaces).filter('checked').map('workspacePublicId').value();

        this.props.manageUserWorkspaces({
            user: this.props.userForWorkspacesManagement,
            workspaceIdsToRemove,
            workspaceIdsToAdd
        })
    }

    render() {
        return (<div className="manage-user-workspaces-overlay">
            <UserIcon/>
            <div className="user-name">{this.props.userForWorkspacesManagement.name}</div>
            <div className="title">Manage User Workspaces</div>
            <div className="workspaces-list">
                {(this.state.associatedWorkspaces.length || null) && <h5>Associated Workspaces:</h5>}
                {this.state.associatedWorkspaces.map(workspace => (
                    <label key={workspace.workspacePublicId} style={{ fontWeight: 600 }}>
                        <input type="checkbox"
                               defaultChecked={true}
                               onChange={() => this.handleCheckboxChange('associatedWorkspaces', workspace.workspacePublicId)}/>
                        {workspace.workspaceName}
                    </label>))}
                {(this.state.unAssociatedWorkspaces.length || null) && <h5>Other Workspaces:</h5>}
                {this.state.unAssociatedWorkspaces.map((workspace) => (
                    <label key={workspace.workspacePublicId}>
                        <input type="checkbox" defaultChecked={false}
                               onChange={() => this.handleCheckboxChange('unAssociatedWorkspaces', workspace.workspacePublicId)}/>
                        {workspace.workspaceName}
                    </label>))}
            </div>
            <div className="button-box">
                <button type="button" className={buttons.cancel} onClick={() => {
                    this.props.manageUserWorkspacesPrompt({})
                }}>Cancel
                </button>
                <button type="submit" className={buttons.primary} disabled={!this.state.changesDone} onClick={() => {
                    this.submitButtonClicked()
                }}>Apply
                </button>
            </div>
            {this.props.manageUserWorkspacesError && <div className="error-message">{this.props.manageUserWorkspacesError}</div>}
        </div>)
    };
}

const mapStateToProps = state => {
    return {
        accountWorkspaces: state.accountsManagement.accountWorkspaces,
        userForWorkspacesManagement: state.accountsManagement.userForWorkspacesManagement,
        manageUserWorkspacesError: state.accountsManagement.manageUserWorkspacesError
    };
};

const mapDispatchToProps = dispatch => {
    return {
        manageUserWorkspacesPrompt: ({ user }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:MANAGE-USER-WORKSPACES-PROMPT",
                payload: user
            })
        },
        manageUserWorkspaces: ({ user, workspaceIdsToRemove, workspaceIdsToAdd }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:MANAGE-USER-WORKSPACES",
                payload: { user, workspaceIdsToRemove, workspaceIdsToAdd }
            })
        }
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(ManageUserWorkspacesOverlay)