import React from 'react';
import { connect } from 'react-redux';
import _ from 'lodash'

import "./Accounts.scss"
import { ReactComponent as WorkspaceIcon } from "ui-components/src/images/2-colors-icons/ic-workspace.svg";
import { ReactComponent as EditPencil } from "ui-components/src/images/monochrome-icons/ic-pencil.svg"
import { ReactComponent as DeleteIcon } from "ui-components/src/images/monochrome-icons/ic-delete.svg"
import { ReactComponent as InlineLoader } from "ui-components/src/images/loaders/inline-loader.svg";
import buttons from "ui-components/src/button/button.module.scss";

class ManageWorkspacesOverlay extends React.Component {
    constructor(props) {
        super(props);

        this.state = {workspaceForRenaming: null, workspaceForDeleting: null};
        this.props.accountWorkspaces.forEach(workspace => {
                this[`${workspace.workspacePublicId}Input`] = React.createRef();
                this.state[`${workspace.workspacePublicId}Input`] = workspace.workspaceName
            }
        );

        this.addNewInput = React.createRef();
        this.renameButtonClicked = this.renameButtonClicked.bind(this);
        this.deleteButtonClicked = this.deleteButtonClicked.bind(this);
        this.cancelRenameButtonClicked = this.cancelRenameButtonClicked.bind(this);
        this.cancelDeleteButtonClicked = this.cancelDeleteButtonClicked.bind(this);
        this.handleInputName = this.handleInputName.bind(this);
    }

    renameButtonClicked({workspace}) {
        this.setState({ workspaceForRenaming: workspace }, () => {
            this[`${workspace.workspacePublicId}Input`].current.focus();
        });
    }

    deleteButtonClicked({workspace}) {
        this.setState({workspaceForDeleting: workspace});
    }

    cancelRenameButtonClicked({workspace}) {
        this.setState({workspaceForRenaming: null, [`${workspace.workspacePublicId}Input`]: workspace.workspaceName});
    }

    cancelDeleteButtonClicked() {
        this.setState({workspaceForDeleting: null});
    }

    renameWorkspace({ workspace, event }) {
        event.preventDefault();

        if (ManageWorkspacesOverlay.isWorkspaceNameValid(this.state[`${workspace.workspacePublicId}Input`])) {
            this.props.editWorkspaceName({ workspace, newName: this.state[`${workspace.workspacePublicId}Input`] });
            this.setState({ workspaceForRenaming: null });
        } else {
            this.props.displayError({ errorMessage: 'Workspace name cannot contain /\\[]?@#$' });
        }
    }

    deleteWorkspace({ workspace }) {
        this.props.deleteWorkspace({ workspace });
        this.setState({ workspaceForDeleting: null });
    }

    handleInputName(event) {
        this.setState({[event.target.name]: event.target.value});
    }

    toggleCreateNewWorkspace(value) {
        this.setState({addNew: value}, () => {
            value && this.addNewInput.current.focus();
        });
    }

    static isWorkspaceNameValid(workspaceName) {
        // Do not allow /\[]?@#
        return /^[^/\\[\]?@#$]+$/.test(workspaceName)
    }

    addWorkspace(event) {
        event.preventDefault();
        if (this.state.addNewInput) {
            if (ManageWorkspacesOverlay.isWorkspaceNameValid(this.state.addNewInput)) {
                this.props.addNewWorkspace({ newName: this.state.addNewInput });
            } else {
                this.props.displayError({ errorMessage: 'Workspace name cannot contain /\\[]?@#$' });
            }
        }
    }

    newWorkspaceAdded(newWorkspace) {
        this[`${newWorkspace.workspacePublicId}Input`] = React.createRef();
        this.setState({
            [`${newWorkspace.workspacePublicId}Input`]: newWorkspace.workspaceName,
            addNew: false
        });
    }

    componentDidUpdate(prevProps) {
        if (!this.props.addNewWorkspacePending  && prevProps.addNewWorkspacePending &&
            this.props.accountWorkspaces.length === prevProps.accountWorkspaces.length + 1) {
            const newWorkspace = _.differenceWith(this.props.accountWorkspaces,prevProps.accountWorkspaces, _.isEqual);

            this.newWorkspaceAdded(newWorkspace[0]);
        }
    }

    onEscPressed(callback){
        return event => {
            if (event.keyCode === 27) callback();
        };
    }

    render() {
        return (<div className="manage-workspaces-overlay">
            <WorkspaceIcon/>
            <div className="user-name">{this.props.account.accountName}</div>
            <div className="title">Manage Account Workspaces</div>
            <button className="add-new-button" onClick={() => this.toggleCreateNewWorkspace(true)}>+&nbsp;&nbsp;Add New Workspace</button>
            <div className="workspace-cards">
                {this.state.addNew && <form className="workspace-card">
                    <input type="text"
                           name="addNewInput"
                           placeholder="New Workspace Name"
                           ref={this.addNewInput}
                           onChange={this.handleInputName}/>
                    {!this.props.addNewWorkspacePending && <button type="button" className="inline-button cancel"
                            onClick={() => this.toggleCreateNewWorkspace(false)}>Cancel
                    </button>}
                    {!this.props.addNewWorkspacePending && <button type="submit" className="inline-button submit"
                                                                   disabled={!this.state.addNewInput}
                            onClick={(event) => this.addWorkspace(event)}>Add
                    </button>}
                    {this.props.addNewWorkspacePending && <InlineLoader className="inline-loader"/>}
                </form>}
                {this.props.accountWorkspaces.map(workspace => {
                    const renaming = this.state.workspaceForRenaming === workspace;
                    const deleting = this.state.workspaceForDeleting === workspace;
                    const renamePending = this.props.workspaceRenamePending === workspace.workspacePublicId;
                    const deletePending = this.props.workspaceDeletePending === workspace.workspacePublicId;
                    // This is to prevent the input from transitioning from uncontrolled to controlled element when new
                    // workspace is created and the state is not yet updated with the input value:
                    const displayInputElement = !deleting && (renaming || this.state[`${workspace.workspacePublicId}Input`]);

                    return (<form key={workspace.workspacePublicId}
                                  className="workspace-card">
                        {displayInputElement && <input type="text"
                                                       name={`${workspace.workspacePublicId}Input`}
                                                       value={this.state[`${workspace.workspacePublicId}Input`]}
                                                       placeholder="Workspace name"
                                                       disabled={!renaming}
                                                       onKeyUp={this.onEscPressed(() => this.cancelRenameButtonClicked({ workspace }))}
                                                       ref={this[`${workspace.workspacePublicId}Input`]}
                                                       onChange={this.handleInputName}
                                                       title={renaming ? '' : this.state[`${workspace.workspacePublicId}Input`]}/>}
                        {!renaming && !renamePending && !deleting && !deletePending && <button
                            className="delete-button" onClick={() => this.deleteButtonClicked({ workspace })}
                            title="Delete">
                            <DeleteIcon/>
                        </button>}
                        {!renaming && !renamePending && !deleting && !deletePending && <button
                            className="edit-button"
                            onClick={() => this.renameButtonClicked({ workspace })}
                            title="Rename">
                            <EditPencil/>
                        </button>}
                        {renaming && <button type="button" className="inline-button cancel"
                                             onClick={() => this.cancelRenameButtonClicked({ workspace })}>Cancel</button>}
                        {renaming && <button type="submit" className="inline-button submit"
                                             disabled={!this.state[`${workspace.workspacePublicId}Input`]}
                                             onClick={event => this.renameWorkspace({ event, workspace })}>
                            Rename
                        </button>}
                        {deleting &&
                        <span className="delete-message">Are you sure you want to delete this workspace?</span>}
                        {deleting && <button type="button" className="inline-button cancel"
                                             onClick={this.cancelDeleteButtonClicked}>Cancel</button>}
                        {deleting && <button type="submit" className="inline-button submit"
                                             onClick={() => this.deleteWorkspace({ workspace })}>Delete</button>}
                        {(renamePending || deletePending) && <InlineLoader className="inline-loader"/>}
                    </form>)
                })}
            </div>
            <div className="button-box">
                <button type="submit"
                        className={buttons.primary}
                        disabled={this.state.addNew || this.state.workspaceForRenaming || this.state.workspaceForDeleting}
                        onClick={() => this.props.closeManageWorkspaces()}>
                    Done
                </button>
            </div>
            {this.props.manageWorkspaceError && <div className="error-message">{this.props.manageWorkspaceError}</div>}
        </div>)
    };
}

const mapStateToProps = state => {
    return {
        account: state.accountsManagement.account,
        accountWorkspaces: state.accountsManagement.accountWorkspaces,
        workspaceRenamePending: state.accountsManagement.workspaceRenamePending,
        workspaceDeletePending: state.accountsManagement.workspaceDeletePending,
        addNewWorkspacePending: state.accountsManagement.addNewWorkspacePending,
        manageWorkspaceError: state.accountsManagement.manageWorkspaceError
    };
};

const mapDispatchToProps = dispatch => {
    return {
        closeManageWorkspaces: () => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:CLOSE-MANAGE-WORKSPACES",
            });
        },
        editWorkspaceName: ({ workspace, newName }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:EDIT-WORKSPACE-NAME",
                payload: { workspace, newName }
            })
        },
        deleteWorkspace: ({ workspace }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:DELETE-WORKSPACE",
                payload: workspace
            })
        },
        addNewWorkspace: ({ newName }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:ADD-NEW-WORKSPACE",
                payload: { newName }
            })
        },
        displayError: ({ errorMessage }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:DISPLAY-WORKSPACES-ERROR",
                payload: { errorMessage }
            })
        }
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(ManageWorkspacesOverlay)