import React from 'react';
import { connect } from 'react-redux';
import { ReactComponent as UserIcon } from "ui-components/src/images/monochrome-icons/ic-user.svg";
import buttons from 'ui-components/src/button/button.module.scss';
import Loader from "../../Loader";

const RemoveUserOverlay = ({ userForRemoval, removeUserPrompt, removeUser, removeUserError, removeUserPending }) => (
    <div className="remove-user-overlay">
        {removeUserPending && <Loader/>}
        <UserIcon/>
        <div className="user-name">{userForRemoval.name}</div>
        <div className="title">Are you sure you want to remove this user from this account?</div>
        <div className="button-box">
            <button type="button" className={buttons.cancel} onClick={() => {
                removeUserPrompt({})
            }}>Cancel
            </button>
            <button type="submit" className={buttons.primary} onClick={() => {
                removeUser({ associatedUserPublicId: userForRemoval.userPublicId })
            }}>Remove user
            </button>
        </div>
        {removeUserError && <div className="error-message">{removeUserError}</div>}
    </div>);

const mapStateToProps = state => {
    return {
        userForRemoval: state.accountsManagement.userForRemoval,
        removeUserError: state.accountsManagement.removeUserError,
        removeUserPending: state.accountsManagement.removeUserPending
    };
};

const mapDispatchToProps = dispatch => {
    return {
        removeUserPrompt: ({ user }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:REMOVE-USER-PROMPT",
                payload: user
            })
        },
        removeUser: ({ associatedUserPublicId }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:REMOVE-USER",
                payload: { associatedUserPublicId }
            })
        }
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(RemoveUserOverlay)
