import React from 'react'
import { Link } from 'react-router-dom'
import CloudAssessmentSecuredInBrowserBox from "./CloudAssessmentSecuredInBrowserBox"
import { ReactComponent as AwsLogo } from 'ui-components/src/images/third-party-services/logo-aws.svg';
import { ReactComponent as AzureLogo } from 'ui-components/src/images/third-party-services/logo-azure.svg';
import { connect } from 'react-redux'

const ChooseCloudProviderContainer = ({stage, startAgain, clearError, errorMessage}) => {
    if(stage !== "CREDENTIALS") {
        startAgain();
        return <div/>
    } else if (errorMessage){
        clearError();
        return <div/>
    } else {
        return <div className="choose-cloud-provider-container">
            <p className="description">We will run a quick assessment of your cloud storage, measuring both storage efficiency and data protection levels, looking for unused resources and analyzing snapshot practices.</p>
            <CloudAssessmentSecuredInBrowserBox/>
            <h5>Where would you like to run the assessment?</h5>
            <div className="providers-container">
                <Link className="provider-box left" to="/cloud-assessment/azure">
                    <AzureLogo/>
                </Link>
                <Link className="provider-box right" to="/cloud-assessment/aws">
                    <AwsLogo/>
                </Link>
            </div>
        </div>
    }
};

const mapDispatchToProps = dispatch => {
    return {
        startAgain: () => {
            dispatch({
                type: "CLOUD-ASSESSMENT:RESET"
            });
        },
        clearError: () => {
            dispatch({
                type: "CLOUD-ASSESSMENT:CLEAR-ERROR"
            })
        }
    }
};

const mapStateToProps = state => {
    return {
        stage: state.cloudAssessment.stage,
        errorMessage: state.cloudAssessment.errorMessage
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(ChooseCloudProviderContainer);