import React, { Component } from 'react'
import { ReactComponent as AwsLogo } from 'ui-components/src/images/third-party-services/logo-aws.svg';
import { ReactComponent as DialogCloseXIcon } from 'ui-components/src/images/monochrome-icons/x-icon.svg';
import { openDialog } from "./../dialog/Dialog"
import {SyntaxHighlighter} from "ui-components"
import { CopyToClipboard } from 'react-copy-to-clipboard';
import { Scrollbars } from 'react-custom-scrollbars';
import { connect } from 'react-redux'
import _ from "lodash"
import scrollToComponent from 'react-scroll-to-component'
import CloudAssessmentSecuredInBrowserBox from "./CloudAssessmentSecuredInBrowserBox"
import NeedHelpContactUsWidget from "./NeedHelpContactUsWidget"
import ExternalLink from "./../widgets/ExternalLink";
import ActionButton from "./../widgets/ActionButton";
import styles from "./CloudAssessmentView.module.scss";
import { FormFieldInput } from "ui-components"
import FormFieldSelect from "./../widgets/FormFieldSelect"

const policy = `
{
    "Version": "2012-10-17",
    "Statement": [
        {
            "Effect": "Allow",
            "Action": [
                "ec2:DescribeSnapshots",
                "ec2:DescribeVolumes",
                "ec2:DescribeImages"
            ],
            "Resource": "*"
        }
    ] 
}
`;


const PolicyRequirementsDialog = ({closeDialog}) =>
    <div>
        <header>
            Policy Requirements
            <button className="transparent" onClick={closeDialog}><DialogCloseXIcon/></button>
        </header>
        <section>
            <Scrollbars
                thumbSize={126}
                style={{ width: "100%", height: "100%"}}
                renderThumbVertical={props => {
                    const style = props.style;
                    return <div {...props} style={{...style, cursor: "pointer", width: "5px", right: 5, borderRadius: "5px", backgroundColor: "#e9e9e9"}} />
                }}>
                <div className="inner">
                    <p> Cloud Assessment requires AWS credentials for one time use.</p>
                    <p> The keys can be temporary and will not be used once the process is finished.</p>
                    <p>For more information about IAM policies, refer to the following AWS documentation:<ExternalLink linkKey="cloudAssessment.credentials.awsIamDocumentation" newTab>Overview of IAM Policies</ExternalLink> and <ExternalLink linkKey="cloudAssessment.credentials.awsManagingIamDocumentation" newTab>Managing IAM Policies.</ExternalLink></p>
                    <p>The following IAM policy is required to perform the assessment:</p>
                    <div style={{position: "relative"}}>
                        <CopyToClipboard text={policy} style={{padding: "10px 20px", position: "absolute", top: 0, right: 0, borderRadius: 4}}><ActionButton category="CloudAssessment" label="CopyPolicyToClipboard">Copy to clipboard</ActionButton></CopyToClipboard>
                        <SyntaxHighlighter language="json" customStyle={{background: "rgb(246, 246, 246)", borderRadius: 4}}>{policy}</SyntaxHighlighter>
                    </div>
                </div>
            </Scrollbars>

        </section>
    </div>
;

const regions = [
    { value: 'us-east-1', label: 'us-east-1 | US East (N. Virginia)' },
    { value: 'us-east-2', label: 'us-east-2 | US East (Ohio)' },
    { value: 'us-west-1', label: 'us-west-1 | US West (N. California)' },
    { value: 'us-west-2', label: 'us-west-2 | US West (Oregon)' },
    { value: 'ca-central-1', label: 'ca-central-1 | Canada (Central)' },
    { value: 'eu-central-1', label: 'eu-central-1 | EU (Frankfurt)' },
    { value: 'eu-west-1', label: 'eu-west-1 | EU (Ireland)' },
    { value: 'eu-west-2', label: 'eu-west-2 | EU (London)' },
    { value: 'eu-west-3', label: 'eu-west-3 | EU (Paris)' },
    { value: 'ap-northeast-1', label: 'ap-northeast-1 | Asia Pacific (Tokyo)' },
    { value: 'ap-northeast-2', label: 'ap-northeast-2 | Asia Pacific (Seoul)' },
    { value: 'ap-northeast-3', label: 'ap-northeast-3 | Asia Pacific (Osaka-Local)' },
    { value: 'ap-southeast-1', label: 'ap-southeast-1 | Asia Pacific (Singapore)' },
    { value: 'ap-southeast-2', label: 'ap-southeast-2 | Asia Pacific (Sydney)' },
    { value: 'ap-south-1', label: 'ap-south-1 | Asia Pacific (Mumbai)' },
    { value: 'sa-east-1', label: 'sa-east-1 | South America (São Paulo)' },
    { value: 'us-gov-west-1', label: 'us-gov-west-1 | GovCloud (US)'}
];

class KeysContainer extends Component {
    constructor(props){
        super(props);


        this.state = {
            accessKey: _.get(props, 'credentials.accessKey', ''),
            secretKey: _.get(props, 'credentials.secretKey', ''),
            region: _.find(regions, {value: (localStorage.getItem('ca-last-region') || 'us-east-1')})
        };
    }

    handleAccessKeyChange(event){
        this.setState({accessKey: event.target.value});
    }

    handleSecretKeyChange(event){
        this.setState({secretKey: event.target.value});
    }

    handleRegionChange(region){
        this.setState({ region })
    }

    triggerError(el){
        if(el && !this.errorEl){
            this.errorEl = el;
            scrollToComponent(el, { offset: -200, align: 'top', duration: 400});
        }
    }

    render () {
        const {errorMessage, performAssessment} = this.props;

        return <div className="keys-container credentials-step">
            <CloudAssessmentSecuredInBrowserBox/>
            <div className="cloud-provider-logo"><AwsLogo/></div>
            <p>Please read the AWS <ActionButton className="a" category="CloudAssessment" label="PoliciesDialog" onClick={(el) => {
                openDialog(<PolicyRequirementsDialog className="cloud-assessment-keys-dialog"/>, el.target)
            }}>Policy Requirements</ActionButton> before you continue</p>

            <form onSubmit={(e) => { e.preventDefault(); performAssessment({accessKey: this.state.accessKey, secretKey: this.state.secretKey, region: this.state.region.value})}}>
                <FormFieldInput type="text" name="accessKey" label="Access Key" value={this.state.accessKey}
                                onChange={this.handleAccessKeyChange.bind(this)} placeholder="e.g. AKIAIOSFODNN7EXAMPLE"
                                autoFocus={true}/>
                <FormFieldInput type="password" name="secretKey" label="Secret Key" value={this.state.secretKey}
                                onChange={this.handleSecretKeyChange.bind(this)}
                                placeholder="e.g. wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"/>
                <FormFieldSelect label="Region"
                                 name="region-selector"
                                 isSearchable={true}
                                 value={this.state.region}
                                 onChange={this.handleRegionChange.bind(this)}
                                 isClearable={false}
                                 options={regions}/>

                <button className={styles["submit-btn"]} type="submit">Start Cloud Assessment</button>

                {errorMessage &&
                    <div className="error" ref={this.triggerError.bind(this)}>
                        {errorMessage}
                    </div>
                }
            </form>
            <NeedHelpContactUsWidget/>
        </div>
    }
}


const mapDispatchToProps = dispatch => {
    return {
        performAssessment: ({accessKey, secretKey, region}) => {
            localStorage.setItem("ca-last-region", region);

            if(!accessKey || !secretKey || !region){
                dispatch({
                    type: "CLOUD-ASSESSMENT:AWS-ERROR-UI",
                    payload: {
                        noAccessKey: !accessKey,
                        noSecretKey: !secretKey,
                        noRegion: !region,
                        isPermissions: true
                    }
                });
            } else {
                dispatch({
                    type: "CLOUD-ASSESSMENT:AWS-STARTED",
                    payload: {accessKey, secretKey, region}
                });
            }
        }
    }
};

const mapStateToProps = state => {
    return {
        errorMessage: state.cloudAssessment.errorMessage,
        credentials: state.cloudAssessment.credentials,
        cloudAssessment: state.cloudAssessment
    };
};

export default connect(mapStateToProps, mapDispatchToProps)(KeysContainer);