import React from 'react';
import connect from "react-redux/es/connect/connect";
import DashboardContainer from "./DashboardContainer";
import { STATUS_ERROR, STATUS_SUCCESS } from "../../actions";
import styles from "./Dashboard.module.scss"

import { ReactComponent as CloudVolumesOntapLogo } from "ui-components/src/images/netapp-services/ic-banner-cvo.svg";
import { ReactComponent as CloudVolumesServiceLogo } from "ui-components/src/images/netapp-services/ic-banner-cvs.svg";
import { ReactComponent as CloudSyncLogo } from "ui-components/src/images/netapp-services/ic-banner-cloud-sync.svg";
import { ReactComponent as CloudBackupLogo } from "ui-components/src/images/netapp-services/ic-banner-cloud-backup.svg";
import { ReactComponent as CloudInsightsLogo } from "ui-components/src/images/netapp-services/ic-banner-cloud-insights.svg";
import { ReactComponent as CloudTieringLogo } from "ui-components/src/images/netapp-services/ic-banner-cloud-tiering.svg";
import { ReactComponent as KubernetesServiceLogo } from "ui-components/src/images/netapp-services/ic-banner-kubernetes.svg";
import { ReactComponent as SaaSBackupLogo } from "ui-components/src/images/netapp-services/ic-banner-saas-backup.svg";
import { ReactComponent as CloudSecureLogo } from "ui-components/src/images/netapp-services/ic-banner-cloud-secure.svg";

import { ReactComponent as CalculatorIcon } from "ui-components/src/images/2-colors-icons/ic-calculator.svg";
import { ReactComponent as PricingIcon } from "ui-components/src/images/2-colors-icons/ic-pricing.svg";
import { ReactComponent as ApiIcon } from "ui-components/src/images/2-colors-icons/ic-api.svg";
import { ReactComponent as DemoIcon } from "ui-components/src/images/2-colors-icons/ic-monthly-demo.svg";

import { ReactComponent as AzureLogo } from 'ui-components/src/images/third-party-services/logo-azure.svg';
import { ReactComponent as GoogleCloudLogo } from 'ui-components/src/images/third-party-services/logo-google-cloud.svg';
import { ReactComponent as AWSLogo } from 'ui-components/src/images/third-party-services/logo-aws.svg';
import { registerFeature } from "../../middlewares/apiMiddleware";

import dashboardsMiddleware from "../../middlewares/featureApis/dashboardsMiddleware";
import Loader from "./../../Loader";
import Loadable from 'react-loadable';
import {Redirect, Route, Switch, NavLink} from "react-router-dom";
import {RightChevron} from "../cloud-assessment/summary-components/Icons";
import ExternalLink from "../widgets/ExternalLink";
const LoadingView = () => <Loader/>;

registerFeature("DASHBOARDS", dashboardsMiddleware);

const CloudSyncActivatedDashboard = Loadable({
    loader: ()  => import('./CloudSyncActivatedDashboard' /* webpackChunkName: "CloudSyncActivatedDashboard" */),
    loading: LoadingView
});


const CloudSyncDashboardDumb = ({ cloudSync, activeFeatures }) => {
    return (cloudSync.status === STATUS_SUCCESS || cloudSync.status === STATUS_ERROR) && <DashboardContainer
        category="services"
        serviceKey="cloudSync"
        title="Cloud Sync"
        Icon={CloudSyncLogo}
        productText="Cloud Sync is NetApp’s service for rapid and secure data synchronization. Whether you need to transfer files between on-premises NFS or CIFS file shares, Amazon S3 object format, Azure Blob, IBM Cloud Object Storage or NetApp StorageGRID® Webscale appliance, Cloud Sync moves the files where you need them quickly and securely."
        gettingStartedLink="dashboards.cloudSync.gettingStarted"
        contactUsEmail="saas.support@netapp.com"
        gettingStartedContent={[
            {
                Icon: DemoIcon,
                title: "FAQ",
                text: "Frequently asked questions",
                linkKey: "dashboards.cloudSync.faq"
            },
            {
                Icon: PricingIcon,
                title: "Supported Sync Relationships",
                text: "Learn about the supported source and target protocols for data transfer",
                linkKey: "dashboards.cloudSync.supportedSyncRelationships"
            },
            {
                Icon: ApiIcon,
                title: "API",
                text: "Cloud Sync Rest API",
                linkKey: "dashboards.cloudSync.api"
            }
        ]}
        footerContent={{
            title: "Cloud Sync Documentation & Support",
            links: [
                {
                    text: "Getting Started Guide",
                    linkKey: "dashboards.cloudSync.gettingStarted"
                },
                {
                    text: "Documentation",
                    linkKey: "dashboards.cloudSync.documentation"
                },
                {
                    text: "FAQ",
                    linkKey: "dashboards.cloudSync.faq"
                },
                {
                    text: "Blog",
                    linkKey: "dashboards.cloudSync.blog"
                }
            ]
        }}
        ActivatedDashboard={activeFeatures.activatedDashboards && CloudSyncActivatedDashboard}
    />
};

const mapStateToPropsCloudSync = state => {
    return {
        cloudSync: state.services.cloudSync,
        activeFeatures: state.features.active
    };
};

export const CloudSyncDashboard = connect(mapStateToPropsCloudSync)(CloudSyncDashboardDumb);

export const CloudVolumesOntapDashboard = () => <DashboardContainer
    category="storage"
    title="Cloud Volumes ONTAP"
    serviceKey="cloudVolumesOntap"
    Icon={CloudVolumesOntapLogo}
    productText="Cloud Volumes ONTAP is a powerful, cost-effective, and easy-to-use data management solution for your cloud workloads. The familiar and reliable Cloud Volumes ONTAP data management software with its data protection and storage efficiency features, now available in the AWS or Azure cloud."
    gettingStartedLink="dashboards.cloudVolumesOntap.gettingStarted"
    contactUsEmail="saas.support@netapp.com"
    gettingStartedContent={[
        {   Icon: CalculatorIcon,
            title: "TCO Calculator",
            text: "Easily calculate your Cloud Volumes ONTAP Total Cost of Ownership on AWS and Azure",
            linkKey: "dashboards.cloudVolumesOntap.tcoCalculators"
        },
        {   Icon: PricingIcon,
            title: "Pricing",
            text: "Cloud Volumes ONTAP pricing for AWS and Azure",
            linkKey: "dashboards.cloudVolumesOntap.pricing"
        },
        {   Icon: ApiIcon,
            title: "API",
            text: "Cloud Volumes ONTAP Rest API",
            linkKey: "dashboards.cloudVolumesOntap.api"
        }
    ]}
    footerContent={{
        title: "Cloud Volumes ONTAP Documentation & Support",
        links: [
            {
                text: "Getting Started Guide",
                linkKey: "dashboards.cloudVolumesOntap.gettingStarted"
            },
            {
                text: "Documentation",
                linkKey: "dashboards.cloudVolumesOntap.documentation"
            },
            {
                text: "API",
                linkKey: "dashboards.cloudVolumesOntap.api"
            },
            {
                text: "Blog",
                linkKey: "dashboards.cloudVolumesOntap.blog"
            }
        ]
    }}
/>;

const CVSAzure = () => <React.Fragment>
    <p>A first-party Microsoft Azure service that is built together with NetApp delivering extremely low latency and high throughput file services for file-based applications with support for NFS and SMB file shares.<ExternalLink linkKey="launchPad.marketing.cloudVolumesServiceAzure" trackCategory="dashboards" className={styles['cvs-read-more']} newTab>Learn More<RightChevron/></ExternalLink></p>
    <ExternalLink linkKey="launchPad.services.cloudVolumesServiceAzurePreview" trackCategory="dashboards" className={styles['cta-no-center']} newTab>Register for Preview</ExternalLink>
</React.Fragment>;

const CVSGCP = () => <React.Fragment>
    <p>High-Performance, managed file storage, fully integrated with and supported by Google Cloud<ExternalLink linkKey="launchPad.marketing.cloudVolumesServiceGcp" trackCategory="dashboards" className={styles['cvs-read-more']} newTab>Learn More<RightChevron/></ExternalLink></p>
    <ExternalLink linkKey="launchPad.services.cloudVolumesServiceGooglePreview" trackCategory="dashboards" className={styles['cta-no-center']} newTab>Register for Preview</ExternalLink>
</React.Fragment>;

const CVSAWS = () => <React.Fragment>
    <p>Delivers High Performance File Services to Your Business Critical Applications in AWS Cloud <ExternalLink linkKey="launchPad.marketing.cloudVolumesServiceAws" trackCategory="dashboards" className={styles['cvs-read-more']} newTab>Learn More<RightChevron/></ExternalLink></p>
    <ExternalLink linkKey="launchPad.services.cloudVolumesServiceAws" trackCategory="dashboards" className={styles['cta-no-center']} newTab>Go to CVS AWS</ExternalLink>
</React.Fragment>;

const CloudVolumesServiceCustom = () => <section className={styles["cloud-volumes-service-custom"]}>
    <h3>Delivers High Performance File Services to Your Business Critical Applications</h3>
    <div className={styles["cloud-volumes-service-switcher-container"]}>
        <NavLink to="/dashboard/cloud-volumes-service/azure" className={styles['cloud-volumes-service-switcher']} activeClassName={styles['cvs-active']}><AzureLogo/></NavLink>
        <NavLink to="/dashboard/cloud-volumes-service/gcp" className={styles['cloud-volumes-service-switcher']} activeClassName={styles['cvs-active']}><GoogleCloudLogo/></NavLink>
        <NavLink to="/dashboard/cloud-volumes-service/aws" className={styles['cloud-volumes-service-switcher']} activeClassName={styles['cvs-active']}><AWSLogo/></NavLink>
    </div>
    <div className={styles["cloud-volumes-service-container"]}>
        <Switch>
            <Route path="/dashboard/cloud-volumes-service/azure" render={() => <CVSAzure/>}/>
            <Route path="/dashboard/cloud-volumes-service/gcp" render={() => <CVSGCP/>}/>
            <Route path="/dashboard/cloud-volumes-service/aws" render={() => <CVSAWS/>}/>
            <Redirect to="/dashboard/cloud-volumes-service"/>
        </Switch>
    </div>
</section>;

export const CloudVolumesServiceDashboard = () => <DashboardContainer
    category="storage"
    title="Cloud Volumes Service"
    serviceKey="cloudVolumesService"
    Icon={CloudVolumesServiceLogo}
    CustomPane={CloudVolumesServiceCustom}
/>;

export const NetAppKubernetesServiceDashboard = () => <DashboardContainer
    category="controls"
    title="NetApp Kubernetes Service"
    serviceKey="kubernetesService"
    Icon={KubernetesServiceLogo}
    productText="The Universal Control Plane for Managed Kubernetes now available for everyone. Scale from 1 developer to thousands. The simplest way to deploy a Kubernetes cluster to the clouds. Deploy a production-ready Kubernetes cluster in 3 clicks when you want and where you want it."
    gettingStartedLink="dashboards.kubernetesService.gettingStarted"
/>;

export const CloudInsightsDashboard = () => <DashboardContainer
    category="analytics"
    title="Cloud Insights"
    serviceKey="cloudInsights"
    Icon={CloudInsightsLogo}
    productText="Powerful, reliable, easy-to-use and cost effective, Cloud Volumes ONTAP is the data management solution for your cloud workloads. With data protection and storage efficiency features, Cloud Volumes ONTAP is now available for AWS and Azure clouds."
    gettingStartedLink="dashboards.cloudInsights.gettingStarted"
/>;

export const SaaSBackupDashboard = () => <DashboardContainer
    category="services"
    title="SaaS Backup"
    serviceKey="saasBackup"
    Icon={SaaSBackupLogo}
    productText="Is your Software-as-a Service data secure? NetApp’s SaaS Backup solution helps guard your data from threats or accidental deletion."
    gettingStartedLink="dashboards.saasBackup.gettingStarted"
/>;

export const CloudSecureDashboard = () => <DashboardContainer
    category="services"
    title="Cloud Secure"
    serviceKey="cloudSecure"
    Icon={CloudSecureLogo}
    productText="Securely innovate by gaining actionable intelligence on insider threats."
/>;

export const CloudTieringDashboard = () => <DashboardContainer
    category="services"
    title="Cloud Tiering"
    serviceKey="cloudTiering"
    Icon={CloudTieringLogo}
    productText="Reduce storage costs by automatically tiering infrequently-used data to object storage in the cloud. Cloud Tiering enables you to provide high-performance storage for a larger set of applications at lower cost"
/>;

export const CloudBackupServiceDashboard = () => <DashboardContainer
    category="services"
    title="Cloud Backup Service"
    serviceKey="cloudBackup"
    Icon={CloudBackupLogo}
    productText="Get started with Cloud Volumes Service, and experience how the full set of data protection features can provide superior RTO and RPO of your cloud-born data."
/>;