import { Link } from "react-router-dom";
import React from "react";
import classNames from "classnames";
import TextTruncate from 'react-text-truncate';

import cssGrid from "ui-components/src/grid/grid.module.scss";
import card from "ui-components/src/card/card.module.scss";
import styles from "./CloudVolumeServiceHyperScalerView.module.scss";

import { ReactComponent as AssessmentIcon } from "ui-components/src/images/2-colors-icons/ic-assessments.svg";
import { ReactComponent as ContactUsIcon } from "ui-components/src/images/2-colors-icons/contact-us.svg";
import { ReactComponent as DemoIcon } from "ui-components/src/images/2-colors-icons/demo.svg";
import { ReactComponent as DocumentationIcon } from "ui-components/src/images/2-colors-icons/ic-documentation.svg";
import { ReactComponent as CloudVolumesLogo } from "ui-components/src/images/netapp-services/ic-cvs.svg";
import { ReactComponent as PartnersIcon } from 'ui-components/src/images/2-colors-icons/ic-partner.svg';
import { ReactComponent as IntegrationInstructionsIcon } from 'ui-components/src/images/2-colors-icons/ic-integration-instructions.svg';

import { openDialog } from "../dialog/Dialog";
import { ContactUsDialog } from "../dialog/ContactUsDialogs";
import ExternalLink from "./../widgets/ExternalLink";
import CloudVolumesServiceAzureContent from './sales-content/cloudVolumesServiceAzureContent';
import CloudVolumesServiceAwsContent from './sales-content/cloudVolumesServiceAwsContent';
import CloudVolumesServiceGoogleContent from './sales-content/cloudVolumesServicesGoogleContent';
import ReactMarkdown from "react-markdown";

const CloudVolumesServiceAzureTopButtons = () =>
    <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-md"], cssGrid["col-3-lg"])}>
        <Link className={card.card} to="/netapp-internal/cloud-volumes-service/azure/customer-content">
            <PartnersIcon/>
            <div>Customer Content</div>
        </Link>
        <Link className={card.card} to="/netapp-internal/cloud-volumes-service/azure/sales-tools">
            <IntegrationInstructionsIcon/>
            <div>Selling Tools</div>
        </Link>
        <ExternalLink className={card.card} href={CloudVolumesServiceAzureContent.demo} linkKey="internal.sales.cloudVolumesService.azure.demo" newTab>
            <DemoIcon/>
            <div>Demo Environment</div>
        </ExternalLink>
        <ExternalLink className={card.card} linkKey="mainNav.cloudAdvisor" trackCategory="internal" newTab>
            <AssessmentIcon/>
            <div>On-Prem Assessment</div>
        </ExternalLink>
        <ExternalLink className={card.card} href={CloudVolumesServiceAzureContent.technicalDocumentation} linkKey="internal.sales.cloudVolumesService.azure.technicalDocumentation" newTab>
            <DocumentationIcon/>
            <div>Technical Documentation</div>
        </ExternalLink>
        <button className={card.card}
                onClick={(el) => openDialog(<ContactUsDialog email={CloudVolumesServiceAzureContent.contactMail} className="contact-us-dialog" noChat/>, el.target)}>
            <ContactUsIcon/>
            <div>Contact Us</div>
        </button>
    </div>
;

const CloudVolumesServiceAwsTopButtons = () =>
    <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-md"], cssGrid["col-3-lg"])}>
        <Link className={card.card} to="/netapp-internal/cloud-volumes-service/aws/customer-content">
            <PartnersIcon/>
            <div>Customer Content</div>
        </Link>
        <Link className={card.card} to="/netapp-internal/cloud-volumes-service/aws/sales-tools">
            <IntegrationInstructionsIcon/>
            <div>Selling Tools</div>
        </Link>
        <ExternalLink className={card.card} href={CloudVolumesServiceAwsContent.demo} linkKey="internal.sales.cloudVolumesService.aws.demo" newTab>
            <DemoIcon/>
            <div>Demo Environment</div>
        </ExternalLink>
        <ExternalLink className={card.card} linkKey="mainNav.cloudAdvisor" trackCategory="internal" newTab>
            <AssessmentIcon/>
            <div>On-Prem Assessment</div>
        </ExternalLink>
        <ExternalLink className={card.card} href={CloudVolumesServiceAwsContent.technicalDocumentation} linkKey="internal.sales.cloudVolumesService.aws.technicalDocumentation" newTab>
            <DocumentationIcon/>
            <div>Technical Documentation</div>
        </ExternalLink>
        <button className={card.card}
                onClick={(el) => openDialog(<ContactUsDialog email={CloudVolumesServiceAwsContent.contactMail} className="contact-us-dialog" noChat/>, el.target)}>
            <ContactUsIcon/>
            <div>Contact Us</div>
        </button>
    </div>
;

const CloudVolumesServiceGoogleTopButtons = () =>
    <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-md"], cssGrid["col-3-lg"])}>
        <Link className={card.card} to="/netapp-internal/cloud-volumes-service/google/customer-content">
            <PartnersIcon/>
            <div>Customer Content</div>
        </Link>
        <Link className={card.card} to="/netapp-internal/cloud-volumes-service/google/sales-tools">
            <IntegrationInstructionsIcon/>
            <div>Selling Tools</div>
        </Link>
        <ExternalLink className={card.card} href={CloudVolumesServiceGoogleContent.demo} linkKey="internal.sales.cloudVolumesService.google.demo" newTab>
            <DemoIcon/>
            <div>Demo Environment</div>
        </ExternalLink>
        <ExternalLink className={card.card} linkKey="mainNav.cloudAdvisor" trackCategory="internal" newTab>
            <AssessmentIcon/>
            <div>On-Prem Assessment</div>
        </ExternalLink>
        <ExternalLink className={card.card} href={CloudVolumesServiceGoogleContent.technicalDocumentation} linkKey="internal.sales.cloudVolumesService.google.technicalDocumentation" newTab>
            <DocumentationIcon/>
            <div>Technical Documentation</div>
        </ExternalLink>
        <button className={card.card}
                onClick={(el) => openDialog(<ContactUsDialog email={CloudVolumesServiceGoogleContent.contactMail} className="contact-us-dialog" noChat/>, el.target)}>
            <ContactUsIcon/>
            <div>Contact Us</div>
        </button>
    </div>
;

class InfoCard extends React.Component {
    constructor(props) {
        super(props);
        this.cardItemRef = React.createRef();
        this.scrollToItem = this.scrollToItem.bind(this);
    }

    scrollToItem() {
        setTimeout(() => {
            if(this.cardItemRef.current) {
                console.log(this.cardItemRef);
                window.scrollTo(0, this.cardItemRef.current.offsetTop - 300);
            }
        });
    }

    render() {
        const {item, gettingStarted, card} = this.props;
        const cardStyle = card === item.title ? styles["highlighted-info-card"] : (gettingStarted ? styles["home-info-card"] : styles["content-info-card"]);
        card === item.title && this.scrollToItem();
        if (item.contactMail) {
            return (
                <button className={cardStyle}
                        onClick={(el) => openDialog(<ContactUsDialog email={item.contactMail} className="contact-us-dialog" noChat/>, el.target)}>
                    <span ref={this.cardItemRef} className={styles.title}>{item.title}</span>
                    {item.tags && <span className={styles.keywords}>{item.tags.join(' | ')}</span>}
                    {item.agenda && <ReactMarkdown className={styles.details} source={item.agenda}/>}
                    {/*{item.description && <span className={styles.details}>{item.description}</span>}*/}
                    {item.description && <div className={styles.details} title={item.description}><TextTruncate line={3} truncateText="…" text={item.description}/></div>}
                </button>
            );
        } else if(item.link) {
            return (
                <Link to={item.link} className={cardStyle}>
                    <span ref={this.cardItemRef} className={styles.title}>{item.title}</span>
                    {item.tags && <span className={styles.keywords}>{item.tags.join(' | ')}</span>}
                    {item.agenda && <ReactMarkdown className={styles.details} source={item.agenda}/>}
                    {/*{item.description && <span className={styles.details}>{item.description}</span>}*/}
                    {item.description && <div className={styles.details} title={item.description}><TextTruncate line={1} truncateText="…" text={item.description}/></div>}
                </Link>
            );
        } else {
            return (
                <ExternalLink href={item.href} className={cardStyle} linkKey={item.linkKey} newTab>
                    <span ref={this.cardItemRef} className={styles.title}>{item.title}</span>
                    {item.tags && <span className={styles.keywords}>{item.tags.join(' | ')}</span>}
                    {item.agenda && <ReactMarkdown className={styles.details} source={item.agenda}/>}
                    {/*{item.description && <span className={styles.details}>{item.description}</span>}*/}
                    {item.description && <div className={styles.details} title={item.description}><TextTruncate line={3} truncateText="…" text={item.description}/></div>}
                </ExternalLink>
            );
        }
    }
}

const HyperScalerView = ({hyperScalerInfo, topButtons}) => {
    const TopButtons = topButtons;
    return <div className="sales-tools-main service-view">
        <h4 className="service-title"><CloudVolumesLogo className="service-icon"/>{hyperScalerInfo.productName + ` Home`}</h4>
        <TopButtons/>

        {hyperScalerInfo.whatsNew.length > 0 && <h4>What's New</h4>}

        <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-md"], cssGrid["col-2-lg"])}>
            {hyperScalerInfo.whatsNew.map(item => <InfoCard key={item.title} item={item} gettingStarted/>)}
        </div>

        {hyperScalerInfo.gettingStarted.length > 0 && <h4>Getting Started</h4>}

        <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-md"], cssGrid["col-2-lg"])}>
                {hyperScalerInfo.gettingStarted.map(item => <InfoCard key={item.title} item={item} gettingStarted/>)}
        </div>

    </div>
};

const HyperScaleContentView = ({productName, infoItems, contentTitle, card}) => {
    return <div className="sales-tools-main service-view">
        <h4 className="service-title"><CloudVolumesLogo className="service-icon"/>{productName + ` ${contentTitle}`}</h4>
        <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-md"], cssGrid["col-2-lg"])}>
            {infoItems.map(item => <InfoCard card={card} key={item.title} item={item}/>)}
        </div>
    </div>
};

const CloudVolumesServicesAzureHome = () => {
    return (
        <HyperScalerView
            hyperScalerInfo={CloudVolumesServiceAzureContent}
            topButtons={CloudVolumesServiceAzureTopButtons}
        />
    );
};

const CloudVolumesServicesAwsHome = () => {
    return (
        <HyperScalerView
            hyperScalerInfo={CloudVolumesServiceAwsContent}
            topButtons={CloudVolumesServiceAwsTopButtons}
        />
    );
};

const CloudVolumesServicesGoogleHome = () => {
    return (
        <HyperScalerView
            hyperScalerInfo={CloudVolumesServiceGoogleContent}
            topButtons={CloudVolumesServiceGoogleTopButtons}
        />
    );
};

const CloudVolumesServicesAzureSalesTools = ({card}) => {
    return (
        <HyperScaleContentView
            productName={CloudVolumesServiceAzureContent.productName}
            contentTitle={"Sales Tools"}
            infoItems={CloudVolumesServiceAzureContent.salesItems}
            card={card}
        />
    );
};

const CloudVolumesServicesAzureCustomerContent = ({card}) => {
    return (
        <HyperScaleContentView
            productName={CloudVolumesServiceAzureContent.productName}
            contentTitle={"Customer Content"}
            infoItems={CloudVolumesServiceAzureContent.customerContent}
            card={card}
        />
    );
};

const CloudVolumesServicesAwsSalesTools = ({card}) => {
    return (
        <HyperScaleContentView
            productName={CloudVolumesServiceAwsContent.productName}
            contentTitle={"Sales Tools"}
            infoItems={CloudVolumesServiceAwsContent.salesItems}
            card={card}
        />
    );
};

const CloudVolumesServicesAwsCustomerContent = ({card}) => {
    return (
        <HyperScaleContentView
            productName={CloudVolumesServiceAwsContent.productName}
            contentTitle={"Customer Content"}
            infoItems={CloudVolumesServiceAwsContent.customerContent}
            card={card}
        />
    );
};

const CloudVolumesServicesGoogleSalesTools = ({card}) => {
    return (
        <HyperScaleContentView
            productName={CloudVolumesServiceGoogleContent.productName}
            contentTitle={"Sales Tools"}
            infoItems={CloudVolumesServiceGoogleContent.salesItems}
            card={card}
        />
    );
};

const CloudVolumesServicesGoogleCustomerContent = ({card}) => {
    return (
        <HyperScaleContentView
            productName={CloudVolumesServiceGoogleContent.productName}
            contentTitle={"Customer Content"}
            infoItems={CloudVolumesServiceGoogleContent.customerContent}
            card={card}
        />
    );
};

export {
    CloudVolumesServicesAzureHome,
    CloudVolumesServicesAwsHome,
    CloudVolumesServicesGoogleHome,
    CloudVolumesServicesAzureSalesTools,
    CloudVolumesServicesAwsSalesTools,
    CloudVolumesServicesGoogleSalesTools,
    CloudVolumesServicesAzureCustomerContent,
    CloudVolumesServicesAwsCustomerContent,
    CloudVolumesServicesGoogleCustomerContent
}
