import React from 'react'
import { connect } from 'react-redux'
import { ReactComponent as FaqIcon } from 'ui-components/src/images/monochrome-icons/bullet-chevron-icon.svg';
import classNames from "classnames"
import "./FeatureFlags.scss"

const FeatureFlags = ({features, toggleFeature, demoMode}) => {
    return <div className="feature-flags">
        <h4>Feature Flags</h4>
        <ul>
            <li><FaqIcon/>Feature flags are used to enable/disable specific features</li>
            <li><FaqIcon/>Toggling of the flags is persisted per user per browser</li>
            <li><FaqIcon/>Features can be toggled on/off for debug/development purposes, or for demo/video purposes</li>
            <li><FaqIcon/>Feature flags affect Cloud Central and the widget</li>
            <li><FaqIcon/>Some features may appear have been deployed to staging, but not production. Their toggles won't appear in production.</li>
        </ul>

        <div className="features-table">
            {features.map(({key, title, status, toggleAble}) => {
                return <div className="row" key={key}>
                    <div className="description">{title}</div>
                    <div className={classNames("status", {on: status === "ON"})}>{status}</div>
                    <div className="toggle">
                        {toggleAble && <button className="primary" onClick={() => toggleFeature(key)}>TOGGLE</button>}
                        {!toggleAble && <span>Always on in {process.env.REACT_APP_STAGE}</span>}
                    </div>
                </div>
            })}
        </div>

      <div style={{marginTop: 50}}>
          <h4>DEMO MODE</h4>
          <ul>
              <li><FaqIcon/>Enabling demo mode puts all of Cloud Central and it's feature into Demo Mode</li>
              <li><FaqIcon/>Most API calls and complex feature functionality will be simulated</li>
              <li><FaqIcon/>This is good for demos, but less good for production</li>
              <li><FaqIcon/>For example, demo assessments will always return mocked values and will not make AWS/Azure calls</li>
          </ul>

          <div className="features-table">
              <div className="row">
                  <div className="description">Enables Demo Mode for all Cloud Central</div>
                  <div className={classNames("status", {on: demoMode})}>{demoMode ? "ENABLED" : "DISABLED"}</div>
                  <div className="toggle">
                      <button className="primary" onClick={() => toggleFeature("demoMode")}>{demoMode ? "DISABLE" : "ENABLE"}</button>
                  </div>
              </div>
          </div>
      </div>
    </div>;
};

const mapStateToProps = state => {
    return {
        features: state.features.list,
        demoMode: state.features.active.demoMode
    };
};

const mapDispatchToProps = dispatch => {
    return {
        toggleFeature: featureKey => {
            dispatch({
                type: "FEATURES:TOGGLE-FEATURE",
                payload: featureKey
            })
        }
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(FeatureFlags)