import React from 'react'
import './Misc.scss'
import AppHeader from 'components/AppHeader'

export default () => {
    return <div>
        <AppHeader hideWidgets={true}/>

        <div className="misc-header" style={{marginTop: 60}}>
            <h1>LDAP Integration Instructions</h1>
        </div>

        <div className="misc-instructions" style={{padding: "0 80px"}}>
            <p>The following steps describe how to set up your company's LDAP to integrate with NetApp Cloud Central. Once the integration is complete, any user in your LDAP's system will be able to log in to NetApp Cloud Central and its related services using their LDAP credentials.</p>
            <h4 style={{margin: "20px 0 0 0"}}>
                Before you begin
            </h4>
            <ul>
                <li>You should have a running LDAP server which can be accessed from a separate agent that will be launched with the following instructions.</li>
                <li>Your LDAP will provide us with identity information for each logged in user. For a successful login with NetApp Cloud Central, we require that each user has an email address, and that the LDAP server provides us with this email address.</li>
            </ul>
            <h4 style={{margin: 0}}>
                Instructions
            </h4>
            <ol>
                <li>Sign up to <a href="/">Cloud Central</a> and you will receive an email to verify your address. Verify your email address.</li>
                <li>
                    <p>Contact the NetApp Cloud Central team via Intercom or at <a href="mailto:saas.support@netapp.com">saas.support@netapp.com</a>. We will use the company name you entered on sign up and the email domain from your email address for setting up your LDAP connection.</p>
                    <p>After receiving your information, the Cloud Central team initiates the LDAP integration process and provides you with the parameters required for the next step:</p>
                    <ul>
                        <li>The ticket URL for setting up an LDAP agent</li>
                        <li>A connection name to use when logging in via the API</li>
                    </ul>
                </li>
                <li>
                    <p>
                        Manually set up an agent that can access your company's LDAP server and that has outbound internet access so it can communicate with our authentication provider (domain: https://netapp-cloud-account.auth0.com).
                    </p>

                    <p>
                        The agent software is provided by our authentication provider (Auth0). You can find the setup instructions and installer <a href="https://auth0.com/docs/connector/install">here</a>.
                    </p>

                    <p>
                        We suggest installing the Windows version of the agent. If this is not sufficient, it is possible to install the agent on non-Microsoft platforms, although the installation is more complicated. Further information on the agent, the design overview, its prerequisites, and how to install it on non-Microsoft platforms can be found at the <a href="https://auth0.com/docs/connector">documentation site of our authentication provider</a>.
                    </p>

                    <p>
                        During the agent installation process, you must provide the ticket URL that we sent to you.
                    </p>
                </li>

                <li>
                    <p>Once the agent has been successfully configured and is able to communicate with both Auth0 and your LDAP server, contact the NetApp Cloud Central team so we can finalize the integration process.</p>
                    <p>After we finalize the process, we will contact you to let you know that the integration process is complete.</p>
                </li>

                <li>
                    <p>Log in to NetApp Cloud Central services using your LDAP credentials.</p>
                    <p>When you type your email address in the email field, Cloud Central automatically detects your company's connection. You can then provide your LDAP credentials to complete the login.</p>
                </li>
            </ol>
        </div>

    </div>
}