import React from 'react';
import connect from "react-redux/es/connect/connect";
import styles from './NavMenu.module.scss';
import classNames from 'classnames';
import { NavLink } from 'react-router-dom';
import {openDialog} from "../dialog/Dialog";
import {ContactUsDialog} from "../dialog/ContactUsDialogs";
import { ReactComponent as SectionIcon } from "ui-components/src/images/monochrome-icons/ic-round-arrow.svg";
import { ReactComponent as DashboardIcon } from "ui-components/src/images/monochrome-icons/ic-dashboard.svg";
import { ReactComponent as MenuArrow } from 'ui-components/src/images/monochrome-icons/ic-menu-arrow.svg';
import {withRoutingContext} from "./../RoutingContext";
import ExternalLink from "../widgets/ExternalLink";

import { ReactComponent as CloudVolumesLogo }  from 'ui-components/src/images/netapp-services/ic-cvs.svg';
import { ReactComponent as ONTAPCloudLogo } from 'ui-components/src/images/netapp-services/ic-cvo.svg';
import { ReactComponent as CloudSyncLogo } from 'ui-components/src/images/netapp-services/ic-cloud-sync.svg';
import { ReactComponent as SaaSBackupLogo } from 'ui-components/src/images/netapp-services/ic-saas-backup.svg';
import { ReactComponent as OCILogo } from 'ui-components/src/images/netapp-services/ic-cloud-insights.svg';
import { ReactComponent as CloudSentryLogo } from 'ui-components/src/images/netapp-services/ic-cloud-sentry.svg';
import { ReactComponent as KubernetesServiceLogo } from 'ui-components/src/images/netapp-services/ic-kubernetes.svg';
import { ReactComponent as CloudTieringLogo } from 'ui-components/src/images/netapp-services/ic-cloud-tiering.svg';
import { ReactComponent as CloudBackupLogo } from 'ui-components/src/images/netapp-services/ic-cloud-backup.svg';
import ActionButton from "./../widgets/ActionButton"
import CloudVolumesDialogHandler from "./../launch-pad/CloudVolumesDialogHandler";
import CloudVolumesOntapHandler from "./../launch-pad/CloudVolumesOntapHandler";
import { trackInternalLink } from "./../../utils/mrTracker"

import AnimateHeight from "react-animate-height";

import ReactCSSTransitionGroup from 'react-addons-css-transition-group'
import * as actions from "../../actions";

const mapStateToProps = state => {
    return {
        launchPadServices: state.services,
        menuOpen: state.nav.menuOpen,
        toolsOpen: state.nav.toolsOpen,
        productsState: state.nav.productsState,
        activeFeatures: state.features.active,
        auth: state.auth
    };
};

const mapButtonDispatchToProps = dispatch => {
    return {
        openMenu: () => {
            dispatch({type: "MAIN-NAV:OPEN-MENU"});
        },
        closeMenu: () => {
            dispatch({type: "MAIN-NAV:CLOSE-MENU"});
        }
    }
};

const mapMenuDispatchToProps = dispatch => {
    return {
        openMenu: () => {
            dispatch({type: "MAIN-NAV:OPEN-MENU"});
        },
        openProducts: () => {
            dispatch({type: "MAIN-NAV:OPEN-PRODUCTS"});
        },
        closeProducts: () => {
            dispatch({type: "MAIN-NAV:CLOSE-PRODUCTS"});
        },
        openTools: () => {
            dispatch({type: "MAIN-NAV:OPEN-TOOLS"});
        },
        closeTools: () => {
            dispatch({type: "MAIN-NAV:CLOSE-TOOLS"});
        },
        linkClick: (link) => {
            dispatch({type: "MAIN-NAV:LINK-CLICK"});
        }
    }
};

const NavMenuButtonDumb = ({menuOpen, openMenu, closeMenu}) => {
  return <button className={classNames(styles.button, {'is-open': menuOpen})} onClick={menuOpen ? closeMenu : openMenu}>
      <div className="bar top"/>
      <div className="bar middle"/>
      <div className="bar bottom"/>
      <svg xmlns="http://www.w3.org/2000/svg" width="28" height="12" viewBox="0 0 28 12">
          <path d="M22.253.226A.843.843 0 0 1 22.83 0c.216 0 .424.081.577.226l4.352 5.223c.154.144.24.34.24.544 0 .204-.086.4-.24.544l-4.352 5.224a.85.85 0 0 1-.797.214.794.794 0 0 1-.585-.552.74.74 0 0 1 .229-.75l3.774-4.68-3.774-4.68a.747.747 0 0 1-.24-.543c-.001-.204.085-.4.238-.544z"/>
      </svg>
  </button>
};

export const NavMenuButton = connect(mapStateToProps, mapButtonDispatchToProps)(NavMenuButtonDumb);

const ServiceLink = ({text, serviceKey, status}) => status === actions.STATUS_PENDING ? <div className={styles['cta-mask']}/> : <ExternalLink trackCategory="mainNav" className="link" linkKey={`launchPad.services.${serviceKey}`}>{text}</ExternalLink>;

const Product = ({Icon, title, text, dashboardLink, launchPadService, serviceKey}) => <div className={styles.product}>
    <div className="service-icon"><Icon/></div>
    <div className="external-action">
        <div className="name">{title}</div>
        {serviceKey !== "cloudVolumesService" && serviceKey !== "cloudVolumesOntap" && launchPadService && <ServiceLink {...launchPadService}/>}
        {serviceKey === "cloudVolumesOntap" && <CloudVolumesOntapHandler trackCategory="mainNav" view={launchPadService.view} data={launchPadService.data}/>}
        {serviceKey === "cloudVolumesService" && <CloudVolumesDialogHandler origin="mainNav"/>}
    </div>
    <div className="internal-action"><NavLink to={dashboardLink} activeClassName="selected"><DashboardIcon/></NavLink></div>
</div>;

const products = [
    {Icon: ONTAPCloudLogo, serviceKey: "cloudVolumesOntap", title: "Cloud Volumes ONTAP", text: "Create Cloud Manager", dashboardLink: "/dashboard/cloud-volumes-ontap"},
    {Icon: CloudVolumesLogo, serviceKey: "cloudVolumesService", title: "Cloud Volumes Service", text: "Get Started", dashboardLink: "/dashboard/cloud-volumes-service"},
    {Icon: KubernetesServiceLogo, serviceKey: "kubernetesService", title: "NetApp Kubernetes Service", text: "Start Free Trial", dashboardLink: "/dashboard/netapp-kubernetes-service"},
    {Icon: OCILogo, serviceKey: "cloudInsights", title: "Cloud Insights", text: "Start Free Trial", dashboardLink: "/dashboard/cloud-insights"},
    {Icon: CloudSyncLogo, serviceKey: "cloudSync", title: "Cloud Sync", text: "Start Free Trial", dashboardLink: "/dashboard/cloud-sync"},
    {Icon: SaaSBackupLogo, serviceKey: "saasBackup", title: "SaaS Backup", text: "Start Free Trial", dashboardLink: "/dashboard/saas-backup"},
    {Icon: CloudSentryLogo, serviceKey: "cloudSecure", title: "Cloud Secure", text: "Start Free Trial", dashboardLink: "/dashboard/cloud-secure"},
    {Icon: CloudTieringLogo, serviceKey: "cloudTiering", title: "Cloud Tiering", text: "Start Free Trial", dashboardLink: "/dashboard/cloud-tiering"},
    {Icon: CloudBackupLogo, serviceKey: "cloudBackup", title: "Cloud Backup Service", text: "Start Free Trial", dashboardLink: "/dashboard/cloud-backup-service"}
];

const Products = ({state, toggle, launchPadServices}) => {
    let height = "auto";
    if(state === "partial") {
        height = 386;
    } else if (state === "closed") {
        height = 55;
    }

    return <AnimateHeight duration={400} easing="ease" height={height} className={styles['collapsing-section']}>
        <section className={classNames("products", {'is-open': state === "open"})}>
            <button className="title" onClick={toggle}>Products <SectionIcon/></button>
            <div>
                {products.map(product => <Product launchPadService={launchPadServices[product.serviceKey] || {}} key={product.serviceKey} {...product}/>)}
            </div>
            { state === "partial" &&
                <div className="more">
                    <button onClick={toggle}>More Products</button>
                </div>
            }
        </section>
    </AnimateHeight>
};


const tools = [
    {isInternal: false, text: "Cloud Advisor", linkKey: "mainNav.cloudAdvisor"},
    {isInternal: true, text: "Cloud Assessment", href: "/cloud-assessment"},
    {isInternal: false, text: "TCO Azure Calculator", linkKey: "mainNav.azureTcoCalculator"},
    {isInternal: false, text: "TCO AWS Calculator", linkKey: "mainNav.awsTcoCalculator"},
];

const Tools = ({isOpen, toggle}) =>
    <AnimateHeight duration={300} height={isOpen ?  "auto" : 55} easing="ease" className={styles['collapsing-section']}>
        <section className={classNames("tools", {'is-open': isOpen})}>
            <button className="title" onClick={toggle}>Tools <SectionIcon/></button>
            <div>
                {tools.map(({isInternal, text, linkKey, href}) => {
                    if (isInternal) {
                        return <NavLink to={href} className={styles.tool} activeClassName="selected" key={text}>{text}</NavLink>
                    } else {
                        return <ExternalLink linkKey={linkKey} className={styles.tool} newTab={true} key={text}>{text}</ExternalLink>
                    }
                })}
            </div>
        </section>
    </AnimateHeight>;

const InternalLink = ({to, children}) => <NavLink to={to} activeClassName="selected" onClick={() => trackInternalLink({category: "MainNav", path: to})}>{children}</NavLink>     ;

const NavMenuDumb = ({openMenu, menuOpen, toolsOpen, productsState, openProducts, closeProducts, openTools, closeTools, activeFeatures, auth, launchPadServices}) => {
    if(menuOpen) {
        document.body.classList.add("cc-mo");
        document.body.classList.remove("cc-mc");
    } else {
        document.body.classList.add("cc-mc");
        document.body.classList.remove("cc-mo");
    }

    let menu = React.createRef();

    if(!menuOpen){
        setTimeout(() => {
            if(menu.current){
                menu.current.scrollTop = 0;
            }
        })
    }

    return <React.Fragment>
        <nav className={classNames(styles.menu, {'is-open': menuOpen})} ref={menu}>
            {auth.authenticated && <React.Fragment>
                { activeFeatures.gettingStarted && <InternalLink to="/getting-started">How to Get Started</InternalLink> }
                <InternalLink to="/my-services">My Services</InternalLink>
                <InternalLink to="/fabric-view">Fabric View</InternalLink>
                <InternalLink to="/workloads">Workloads</InternalLink>
                { activeFeatures.productsNav && <Products launchPadServices={launchPadServices} state={productsState} toggle={productsState === "open" ? closeProducts : openProducts}/> }
                <Tools isOpen={toolsOpen} toggle={toolsOpen ? closeTools : openTools}/>
                { auth.isNetAppInternal && <InternalLink to="/netapp-internal">NetApp Internal</InternalLink> }
            </React.Fragment>}

            <InternalLink to="/developer-hub">API</InternalLink>
            <ExternalLink linkKey="mainNav.statusPage" newTab={true}>Services Status</ExternalLink>
            <ActionButton category="MainNav" label="contactUsDialog" onClick={(el) => openDialog(<ContactUsDialog className="contact-us-dialog"/>, el.target)}>Contact Us</ActionButton>
        </nav>

        <ReactCSSTransitionGroup
            transitionName="enter"
            transitionEnterTimeout={400}
            transitionLeaveTimeout={1}>
            {!menuOpen &&
                <button className={styles['closed-overlay']} onClick={openMenu}>
                    <MenuArrow/>
                </button>
            }
        </ReactCSSTransitionGroup>
    </React.Fragment>
};

export default withRoutingContext(connect(mapStateToProps, mapMenuDispatchToProps)(NavMenuDumb));