import React, { Component } from 'react';
import { ReactComponent as CheckCircle} from './../../images/icons/notifications/checkmark-circle.svg'
import { ReactComponent as ExclamationCircle} from './../../images/icons/notifications/exclamation-circle.svg'
import { ReactComponent as InfoCircle} from './../../images/icons/notifications/info-circle.svg'
import { ReactComponent as XCircle} from './../../images/icons/notifications/x-circle.svg'
import { ReactComponent as XCircleLight} from 'ui-components/src/images/monochrome-icons/x-circle-icon.svg'
import _ from 'lodash';
import * as actions from "./../../actions";
import { connect } from 'react-redux'

class NotificationMenuContent extends Component {
    componentWillMount(){
        this.props.setNotificationsViewed(_.filter(this.props.notifications.data, {visibility: "new"}));
    };

    render(){
        return(
            <div style={{height:"100%"}}>
                <div className="notification-menu-header">
                    <span>Notifications</span>
                    <button className="delete-all-notifications-button" onClick={() => this.props.clearNotifications(this.props.notifications.data)}>Clear All</button>
                </div>
                <div className="notification-menu-content">
                    {this.props.notifications.status === actions.STATUS_SUCCESS && this.props.notifications.data.length === 0 && <div className="no-notifications">No new notifications to display</div> }

                    {this.props.notifications && this.props.notifications.data && this.props.notifications.data.map(notification => (
                        <Notification key={notification.createDate} notification={notification} onDelete={() => this.props.deleteNotification(notification)}/>
                    ))}
                </div>
            </div>
        )}
}

const mapDispatchToProps = dispatch => {
    return {
        clearNotifications: (notifications) => {
            dispatch({
                type: "NOTIFICATIONS:CLEAR",
                payload: notifications
            });
        },
        deleteNotification: (notification) => {
            dispatch({
                type: "NOTIFICATIONS:DELETE",
                payload: notification
            });
        },
        setNotificationsViewed: (notifications) => {
            dispatch({
                type: "NOTIFICATIONS:SET-VIEWED",
                payload: notifications
            });
        }
    }
};

const mapStateToProps = state => {
    return {
        auth: state.auth,
        notifications: state.notifications
    };
};

export default connect(mapStateToProps, mapDispatchToProps)(NotificationMenuContent);

const Notification = props => {
    return (
        <div className="notification-outer">
            <VerticalBar severity={props.notification.severity} visibility={props.notification.visibility} />
                <div className="notification-inner">
                    <div className="notification-date-time">
                        <NotificationIcon severity={props.notification.severity} />
                        <span className="small-vertical-bar">|</span>
                        <span className="notification-date">{getDate(props.notification.createDate)}</span>
                        <span className="small-vertical-bar">|</span>
                        <span className="notification-date">{getTime(props.notification.createDate)}</span>
                        <button className="delete-notification-button" onClick={() => props.onDelete(props.notification)}><XCircleLight/> </button>
                    </div>
                    <div className="notification-title">
                        {getTitle(props.notification.service)}
                    </div>
                    <div className="notification-message" dangerouslySetInnerHTML={{__html: props.notification.message}} />
            </div>
        </div>
    );
};

const VerticalBar = props => {
    return (
        <div>
            {props.severity === "error" && <div className="vertical-bar-error"> </div>}
            {props.severity === "warning" && <div className="vertical-bar-warning"> </div>}
            {props.severity === "info" && <div className="vertical-bar-info"> </div>}
            {props.severity === "success" && <div className="vertical-bar-success"> </div>}
        </div>
    );
};

const NotificationIcon = props => {
    return (
        <div>
            {props.severity === "error" && <XCircle className="icon-error" />}
            {props.severity === "warning" && <ExclamationCircle className="icon-warning"/>}
            {props.severity === "info" && <InfoCircle className="icon-info"/>}
            {props.severity === "success" && <CheckCircle className="icon-success"/>}
        </div>
    );
};

const getDate = createDate => {
    let date = new Date(createDate);
    return date.toLocaleDateString().replace(/\//g, ".");
};

const getTime = createDate => {
    const date = new Date(createDate);
    return date.toLocaleTimeString([], {hour: '2-digit', minute:'2-digit'});
};

const getTitle = service => {
  switch(service){
      case "ontap-cloud":
          return "Cloud Volumes ONTAP";
      default:
          return "NOTIFICATION"
  }
};