import React, { Component } from 'react';
import { ReactComponent as EditIcon } from 'ui-components/src/images/monochrome-icons/edit-pencil-icon.svg'
import { connect } from 'react-redux'

class UserMenuContent extends Component{
    constructor(props){
        super(props);
        this.state = {
            userName: this.props.auth.data["http://cloud.netapp.com/user_metadata"].name,
        };
        this.handleSave = this.handleSave.bind(this);
        this.handleNameChange = this.handleNameChange.bind(this);

        this.handleCancel = this.handleCancel.bind(this);
        this.handleEdit = this.handleEdit.bind(this);
    }

    handleNameChange(event) {
        this.setState({userName: event.target.value});
    }
    handlePasswordChange(){
        this.props.changePasssword();
        this.setState({editPassword: false});
    }


    handleSave() {
        //validate name
        if(this.state.userName.length > 255 || this.state.userName.length < 1){
            this.setState({nameLengthError: true});
            return;
        }
        this.props.updateUserInfo(this.state.userName);
        this.setState({editName: false, nameLengthError: false});
    }

    handleCancel(field){
        switch (field){
            case 'Name':
                this.setState({userName: this.props.auth.data["http://cloud.netapp.com/user_metadata"].name});
                break;
            default:
                break;
        }
        this.setState({editName: false, editPassword: false, nameLengthError: false})
    }

    handleEdit(field){
        switch (field){
            case 'Name':
                this.setState({editName: true, editPassword: false});
                break;
            case 'Password':
                this.setState({editPassword: true, editName: false});
                break;
            default:
                break;
        }
    }


    render(){
        return(
            <div className="user-menu-content">
                <EditableUserInfo title="Name" content={this.state.userName} showEdit={this.state.editName} onChangeFunc={this.handleNameChange} handleCancel={this.handleCancel} handleSave={this.handleSave} handleEdit={this.handleEdit} formatError={this.state.nameLengthError}/>

                {!this.state.editPassword &&
                <div className="user-info-row-outer">
                    <div className="user-info-row-inner">
                        <div className="user-info-text">
                            <div className="user-title-password text-ellipsis">Password</div>
                        </div>
                        <button className="edit-user-info-button" onClick={() => this.handleEdit('Password')}><EditIcon className="edit"/></button>
                    </div>
                </div>}

                {this.state.editPassword &&
                <div className="user-edit-row-outer">
                    <div className="user-edit-row-inner">
                        <div className="user-title text-ellipsis">Password</div>
                        {this.props.auth.scopes["cc:update-password"] &&
                            <div>
                                <p>Click 'Change Password' to receive an email with further instructions</p>
                                <button className="medium cancel-light" onClick={() => this.handleCancel('Password')}>Cancel</button>
                                <button className="medium primary submit-button" onClick={() => this.handlePasswordChange()}>Change Password</button>
                            </div>}
                        {!this.props.auth.scopes["cc:update-password"] &&
                            <div>
                                <p>You are using your corporate credentials to login. To change your password, please contact your IT department.</p>
                                <button className="medium cancel-light" onClick={() => this.handleCancel('Password')}>Done</button>
                            </div>}
                    </div>
                </div>}


                <StaticUserInfo title="Email" content={this.props.auth.data["http://cloud.netapp.com/user_metadata"].email}/>
                <StaticUserInfo title="Company" content={this.props.auth.data["http://cloud.netapp.com/user_metadata"].company}/>

            </div>
        )}
}


const mapStateToProps = state => {
    return {
        auth: state.auth
    };
};

const mapDispatchToProps = dispatch => {
    return {
        updateUserInfo: (newName) => {
            dispatch({
                type: "USER:UPDATE-INFO",
                payload: {
                    newName
                }
            })
        },
        changePasssword: () => {
            dispatch({
                type: "USER:CHANGE-PASSWORD"
            })
        }
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(UserMenuContent);


const StaticUserInfo = props => {
    return (
        <div className="user-info-row-outer">
            <div className="user-info-row-inner-static">
                <div className="user-info-text">
                    <div className="user-text text-ellipsis">{props.content}</div>
                    <div className="user-title text-ellipsis">{props.title}</div>
                </div>
            </div>
        </div>
    );
};

const EditableUserInfo = props => {
    return (
        <div>
            {props.showEdit &&
            <div className="user-edit-row-outer">
                <div className="user-edit-row-inner">
                    <div className="user-title text-ellipsis">{props.title}</div>
                    {props.formatError && <div className="name-length-error">Must be between 1-255 characters</div>}
                    <input type="text" name="name" value={props.content} onChange={props.onChangeFunc} />
                    <button className="medium cancel-light" onClick={() => props.handleCancel(props.title)}>Cancel</button>
                    <button className="medium primary submit-button" onClick={() => props.handleSave()}>Save</button>
                </div>
            </div>}

            {!props.showEdit &&
            <div className="user-info-row-outer">
                <div className="user-info-row-inner">
                    <div className="user-info-text">
                        <div className="user-text text-ellipsis">{props.content}</div>
                        <div className="user-title text-ellipsis">{props.title}</div>
                    </div>
                    <button className="edit-user-info-button" onClick={() => props.handleEdit(props.title)}><EditIcon className="edit"/></button>
                </div>
            </div>}
        </div>
    );
};