import React from 'react';
import ReactDOM from 'react-dom';
import App from './App'
import { prefetch } from './chunks'
import { Provider } from 'react-redux'
import store, { history } from './store'
import {unregister} from './registerServiceWorker';
import './index.scss';
import { Route, Switch, Redirect, Router } from 'react-router-dom'
import ErrorPage from './components/misc/ErrorPage'
import axios from 'axios'
import StandaloneHeader from 'components/standalone-header/StandaloneHeader';
import LdapSupport from 'components/misc/LdapSupport';
import FederationSupport from 'components/misc/FederationSupport';
import querystring from 'query-string';
import { removeLoader } from './Loader.js';
import { trackPageView } from "./utils/mrTracker"
import Intercom from "./components/intercom/Intercom"
import RoutingContext from "./components/RoutingContext"
import {DialogContainer} from "./components/dialog/Dialog";

const auth0 = require('auth0-js');
const Auth = require('./Auth/Auth.js').default;
window.auth0 = auth0;

const search = querystring.parse(window.location.search);
if(search.redirectBack === 'true'){
    window.history.replaceState(null, "", `/?${querystring.stringify({...search, redirectBack: undefined, redirectToLogin: true})}`);
    window.history.back();
} else {
    window.auth = new Auth({
        clientID: window.__auth__.clientId,
        domain: window.__auth__.domain,
        audience: window.__auth__.audience
    });
    axios.defaults.baseURL=window.__react_app_portal_backend_base_url;

    window.axios = axios;

    store.dispatch({type: "AUTH:REFRESH-SSO"});

    history.listen(function (location) {
        trackPageView({location});
    });

    if(search.__hsfp || search.__hssc || search.__hstc){
        delete search.__hsfp;
        delete search.__hssc;
        delete search.__hstc;
        const searchString = querystring.stringify(search);
        history.replace(window.location.pathname + (searchString ? "?" + searchString : ''));
    }

    const Misc = () => {
        removeLoader(true);
        return <React.Fragment>
            <Intercom/>
            <Switch>
                <Route path="/misc/federation-support" exact component={FederationSupport}/>
                <Route path="/misc/error-page" exact component={ErrorPage}/>
                <Route path="/misc/ldap-support" exact component={LdapSupport}/>
                <Route path="/misc" render={() => <Redirect to="/"/>}/>
            </Switch>
        </React.Fragment>
    };

    prefetch.forEach(view => view.preload());

    const MainSwitch = (props) => {
        return <RoutingContext.Provider value={props}>
            <Switch>
                {/*All redirections to misc need to be added to the authMiddleware to avoid unnecessary authentication*/}
                <Route path="/error-page" exact render={() => <Redirect to={`/misc/error-page${window.location.search}`}/>}/>
                <Route path="/ldap-support" exact render={() => <Redirect to="/misc/ldap-support"/>}/>
                <Route path="/header" exact component={StandaloneHeader}/>
                <Route path="/misc" component={Misc}/>
                <Route path="/" component={App} />
            </Switch>
            <DialogContainer/>
        </RoutingContext.Provider>
    };


    ReactDOM.render(
        <Provider store={store}>
            <Router history={history}>
                <Route path="/" component={MainSwitch}/>
            </Router>
        </Provider>,
        document.getElementById('root'));
}

unregister();

