import {demoAwsResponse, demoAzureResponse} from "./../../consts/fixtures"
import {assessGivenRegions} from './../../components/cloud-assessment/cloudAssessor'
import { getAzureSubscriptions, acquireAccessToken, login, logout, assessGivenSubscription } from "./../../components/cloud-assessment/AzureAssessment"
import moment from "moment"
import _ from "lodash"
import numeral from "numeral"
import axios from "axios"
import json2csv from "json2csv";

const transformCommonResponse = (result) => {
    moment.updateLocale('en', {
        relativeTime: {
            m: "1 minute",
            past: "< 60 sec",
            s: "< 60 sec",
            ss: "< 60 sec"
        }
    });
    result.f_reportTime = moment(result.reportTime).format("ll");
    result.f_totalCapacity = numeral(result.totalCapacity * 1024 * 1024 * 1024).format('0.0 ib');
    if (result.protection.averageRPO === null || result.protection.averageRPO === -1) {
        result.protection.f_averageRPO = "- -";
    } else if (result.protection.averageRPO === 0) {
        result.protection.f_averageRPO = "0 seconds";
    } else {
        result.protection.f_averageRPO = moment.duration(result.protection.averageRPO).locale('precise-en').humanize();
    }
    result.efficiency.f_totalCost = numeral(result.efficiency.totalCost).format('$0,0');
    moment.updateLocale('en', null);
};

const transformAwsResponse = (payload) => {
    const report = _.cloneDeep(payload);
    report.provider = "aws";

    _.chain(report.allRegions).forEach(regionResponse => regionResponse.result.region = regionResponse.region).map("result").forEach(result => {
        transformCommonResponse(result);
        result.f_totalVolumes = numeral(result.totalVolumes).format('0,0');
        result.efficiency.f_unusedVolumesCost = numeral(result.efficiency.unusedVolumesCost).format('$0,0');
        result.efficiency.f_unusedSnapshotsCost = numeral(result.efficiency.unusedSnapshotsCost).format('$0,0');
        result.efficiency.f_snapshotsWithoutVolumesCount = numeral(result.efficiency.snapshotsWithoutVolumesCount).format('0,0');
        result.efficiency.f_unattachedVolumesCount = numeral(result.efficiency.unattachedVolumesCount).format('0,0');
        result.protection.f_volumesWithSnapshotsCount = numeral(result.protection.volumesWithSnapshotsCount).format('0,0');
        result.protection.f_volumesWithoutSnapshotsCount = numeral(result.protection.volumesWithoutSnapshotsCount).format('0,0');
    }).value();

    return report;
};

const transformAzureResponse = (payload) => {
    const report = _.cloneDeep(payload);
    const result = report.result;
    report.provider = "azure";

    transformCommonResponse(result);
    result.f_disksCount = numeral(result.disksCount).format('0,0');
    result.efficiency.f_unattachedDisksAnnualCost = numeral(result.efficiency.unattachedDisksAnnualCost).format('$0,0');
    result.efficiency.f_unassociatedSnapshotsAnnualCost = numeral(result.efficiency.unassociatedSnapshotsAnnualCost).format('$0,0');
    result.efficiency.f_unassociatedSnapshotsCount = numeral(result.efficiency.unassociatedSnapshotsCount).format('0,0');
    result.efficiency.f_unattachedDisksCount = numeral(result.efficiency.unattachedDisksCount).format('0,0');
    result.protection.f_disksWithSnapshotsCount = numeral(result.protection.disksWithSnapshotsCount).format('0,0');
    result.protection.f_disksWithoutSnapshotsCount = numeral(result.protection.disksWithoutSnapshotsCount).format('0,0');

    return report;
};

const downloadAsCsv = ({fileName, data}) => {
    if (data.length === 0) return;
    const parser = new json2csv.Parser();

    if (window.navigator.msSaveOrOpenBlob) { //EDGE workaround
        const blob = new Blob([decodeURIComponent(encodeURI(parser.parse(data)))], {type: 'text/csv;charset=utf-8;'});
        navigator.msSaveBlob(blob, `${fileName}.csv`);
    } else {
        const element = document.createElement('a');
        element.setAttribute('href', 'data:text/plain;charset=utf-8,' + encodeURIComponent(parser.parse(data)));
        element.setAttribute('download', `${fileName}.csv`);
        element.style.display = 'none';
        document.body.appendChild(element);

        element.click();

        document.body.removeChild(element);
    }
};

export default ({getState, dispatch, next, action}) => {
    const {type, payload} = action;
    const state = getState();
    const email = _.get(state, "auth.email");
    const demoMode = _.get(state, "features.active.demoMode");

    if(demoMode) {
        /*
        ================
               DEMO MODE
        ================
        */
        if(type === "CLOUD-ASSESSMENT:AWS-STARTED"){
            const transformedResponse = transformAwsResponse(demoAwsResponse);

            const apiAction = {type: "CLOUD-ASSESSMENT:AWS-SUCCESS-API", payload: transformedResponse, trackPayload: true, omitInPayload: []};
            const uiAction = {type: "CLOUD-ASSESSMENT:AWS-SUCCESS-UI", payload: transformedResponse};

            setTimeout(() => {
                dispatch(uiAction);
            }, 2000);

            dispatch(apiAction);
        } else if (type === "CLOUD-ASSESSMENT:AZURE-LOGIN") {
            dispatch({
                type: "CLOUD-ASSESSMENT:PARSE-AZURE-LOGIN-TOKEN",
                payload: {
                    azureLoginToken: "fake-token"
                }
            })
        } else if (type === "CLOUD-ASSESSMENT:AZURE-LOGOUT"){
            window.location.reload();
        } else if (type === "CLOUD-ASSESSMENT:PARSE-AZURE-LOGIN-TOKEN") {
            dispatch({
                type: "CLOUD-ASSESSMENT:STORE-AZURE-ACCESS-TOKEN",
                payload: { accessToken: "demo-access-token", idTokenPayload: {upn: "demouser@netapp.com"} }
            });

            dispatch({
                type: "CLOUD-ASSESSMENT:FETCH-AZURE-SUBSCRIPTIONS"
            });
        } else if (type === "CLOUD-ASSESSMENT:FETCH-AZURE-SUBSCRIPTIONS") {
            dispatch({
                type: "CLOUD-ASSESSMENT:FETCH-AZURE-SUBSCRIPTIONS-SUCCESS",
                payload: { subscriptions: [{subscriptionId: "demo-id-1", displayName: "Main Subscription"}] }
            })
        } else if (type === "CLOUD-ASSESSMENT:AZURE-STARTED") {
            const transformedResponse = transformAzureResponse(demoAzureResponse);

            setTimeout(() => {
                dispatch({
                    type: "CLOUD-ASSESSMENT:AZURE-SUCCESS",
                    payload: transformedResponse,
                    trackPayload: true,
                    omitInPayload: []
                });
            }, 2000);
        } else if (type === "CLOUD-ASSESSMENT:AWS-DOWNLOAD-LISTS" || type === "CLOUD-ASSESSMENT:AZURE-DOWNLOAD-LISTS") {
            payload.forEach(downloadAsCsv);
        }
        /*
        ================
               END DEMO MODE
        ================
        */
    } else {
        if(type === "CLOUD-ASSESSMENT:AWS-STARTED"){
            const {accessKey, secretKey, region} = payload;

            const assessmentPromise = assessGivenRegions({credentials: {accessKeyId: accessKey, secretAccessKey: secretKey}, regions: [region]});
            const startTime = Date.now();
            assessmentPromise.then((response) => {
                const diff = Date.now() - startTime;

                const transformedResponse = transformAwsResponse(response);
                transformedResponse.email = email;

                //Must use cloneDeep because lodash bug: https://github.com/lodash/lodash/issues/3765
                const thinResponseForApi = _.omit(_.cloneDeep(transformedResponse), ['allRegions[0].result.unattachedVolumes', 'allRegions[0].result.notAttachedSnapshots']);
                axios.post("/portal/assessment/assessment-finished", thinResponseForApi);

                const apiAction = {type: "CLOUD-ASSESSMENT:AWS-SUCCESS-API", payload: transformedResponse, trackPayload: true, omitInPayload: ['allRegions[0].result.unattachedVolumes', 'allRegions[0].result.notAttachedSnapshots']};
                const uiAction = {type: "CLOUD-ASSESSMENT:AWS-SUCCESS-UI", payload: transformedResponse};

                if(diff > 5000){
                    dispatch(apiAction);
                    dispatch(uiAction);
                } else {
                    dispatch(apiAction);
                    setTimeout(() => {
                        dispatch(uiAction)
                    }, diff);
                }
            }, (err) => {
                const state = getState();
                const {step, message, isPermissions} = err;

                axios.post("/portal/assessment/assessment-failed", {
                    step,
                    message,
                    isPermissions,
                    accessKey: state.cloudAssessment.credentials.accessKey,
                    email
                });

                dispatch({type: "CLOUD-ASSESSMENT:RESTART-AFTER-ERROR"});
                dispatch({type: "CLOUD-ASSESSMENT:AWS-ERROR-API", payload: { message }, trackPayload: true})
            });
        } else if (type === "CLOUD-ASSESSMENT:AZURE-LOGIN") {
            login();
        } else if (type === "CLOUD-ASSESSMENT:AZURE-LOGOUT"){
            logout();
        } else if (type === "CLOUD-ASSESSMENT:PARSE-AZURE-LOGIN-TOKEN") {
            const azureLoginToken = action.payload.azureLoginToken;

            acquireAccessToken(azureLoginToken).then(({expireTimeout, accessToken, idTokenPayload}) => {
                dispatch({
                    type: "CLOUD-ASSESSMENT:STORE-AZURE-ACCESS-TOKEN",
                    payload: { accessToken, idTokenPayload }
                });

                dispatch({
                    type: "CLOUD-ASSESSMENT:FETCH-AZURE-SUBSCRIPTIONS"
                });

                setTimeout(() => {
                    dispatch({
                        type: "CLOUD-ASSESSMENT:CLEAR-AZURE-ACCESS-TOKEN"
                    })
                }, expireTimeout)
            }, err => {
                dispatch({
                    type: "CLOUD-ASSESSMENT:AZURE-ACCESS-TOKEN-FAILURE",
                    payload: err
                })
            });
        } else if (type === "CLOUD-ASSESSMENT:FETCH-AZURE-SUBSCRIPTIONS") {
            const state = getState();
            const azureAccessToken = state.cloudAssessment.azureAccessToken;

            getAzureSubscriptions(azureAccessToken).then(({data: {value: subscriptions}}) => {
                dispatch({
                    type: "CLOUD-ASSESSMENT:FETCH-AZURE-SUBSCRIPTIONS-SUCCESS",
                    payload: { subscriptions }
                })
            }, err => {
                console.log("cloud assessment fetch subscriptions error");
                console.log(err);
                dispatch({
                    type: "CLOUD-ASSESSMENT:FETCH-AZURE-SUBSCRIPTIONS-FAILED",
                    payload: err
                })
            });
        } else if (type === "CLOUD-ASSESSMENT:AZURE-STARTED") {
            const state = getState();
            const token = state.cloudAssessment.azureAccessToken;
            const subscriptionId = state.cloudAssessment.selectedSubscription.value;
            assessGivenSubscription({subscriptionId, token}).then(response => {
                const transformedResponse = transformAzureResponse(response);
                transformedResponse.email = email;

                const thinResponseForApi = _.omit(transformedResponse, ['result.unattachedDisks', 'result.unassociatedSnapshots']);
                axios.post("/portal/assessment/assessment-finished", thinResponseForApi);

                dispatch({
                    type: "CLOUD-ASSESSMENT:AZURE-SUCCESS",
                    payload: transformedResponse,
                    trackPayload: true,
                    omitInPayload: ['result.unattachedDisks', 'result.unassociatedSnapshots']
                });
            }, err => {
                console.log("Cloud assessment azure error...");
                console.log(err);

                const { message } = err;

                axios.post("/portal/assessment/assessment-failed", {
                    message,
                    email
                });

                dispatch({
                    type: "CLOUD-ASSESSMENT:AZURE-ERROR",
                    payload: { message },
                    trackPayload: true
                })
            })
        } else if (type === "CLOUD-ASSESSMENT:AWS-DOWNLOAD-LISTS" || type === "CLOUD-ASSESSMENT:AZURE-DOWNLOAD-LISTS") {
            payload.forEach(downloadAsCsv);
        }
    }

    return next(action);
};