import axios from "axios"
import csvToJson from 'csvtojson'
import {downloadFile} from './../../utils/utils'
import _ from 'lodash'

const processGridDataForDisplay = (dataAsJson) => {
    //Add space after each comma.
    return dataAsJson.map(row => _.mapValues(row, (datum) => datum.split(',').join(', ')));
};

export default ({dispatch, next, action}) => {
    const {type, payload} = action;
    if (type === "CUSTOMER-SUCCESS:FETCH-STORIES") {
        axios.get('/portal/customer-success-stories')
            .then(
                ({data}) => csvToJson()
                    .fromString(data)
                    .then(jsonArray => dispatch({
                        type: "CUSTOMER-SUCCESS:FETCH-STORIES-SUCCESS",
                        payload: {asJson: processGridDataForDisplay(jsonArray), asCsv: data}
                    })),
                e => dispatch({type: "CUSTOMER-SUCCESS:FETCH-STORIES-ERROR", payload: e}));

        return next({type: "CUSTOMER-SUCCESS:FETCH-STORIES-PENDING"});
    } else if (type === "CUSTOMER-SUCCESS:DOWNLOAD-AS-CSV") {
        downloadFile({fileName: 'CustomerStories.csv', data: payload.data});
    } else if (type === "CUSTOMER-SUCCESS:UPLOAD-FILE") {
        const fileReader = new FileReader();
        fileReader.readAsText(payload);
        fileReader.onloadend = () => axios.put('/portal/customer-success-stories', {content: fileReader.result})
            .then(() => {
                    dispatch({type: "CUSTOMER-SUCCESS:UPLOAD-FILE-SUCCESS"});
                    dispatch({type: "CUSTOMER-SUCCESS:FETCH-STORIES"});

                    setTimeout(() => {
                        dispatch({type: "CUSTOMER-SUCCESS:UPLOAD-FILE-CLEAR-CLIENT-DETAILS-MESSAGE"})
                    },4000)
                },
                e => dispatch({type: "CUSTOMER-SUCCESS:UPLOAD-FILE-ERROR", payload: e})
            );

        return next({type: "CUSTOMER-SUCCESS:UPLOAD-FILE-PENDING"});
    }

    return next(action);
};
