import axios from "axios";
import _ from "lodash";

let developersAxios = _.once(() => {
    return window.auth.refreshSso({ audience: "https://governance.cloud.netapp.com", scope: "cc:clients" })
        .then(({ accessToken, scope }) => {
            if (!_.includes(scope, 'cc:clients')) {
                return Promise.reject({response: {status: 403}})
            }

            return axios.create({
                baseURL: window.__react_app_portal_backend_base_url,
                headers: { Authorization: `Bearer ${accessToken}` }
            });
        });
});


export default ({ getState, dispatch, next, action }) => {
    const { type, payload } = action;
    if (type === "DEVELOPERS:FETCH-CLIENTS-LIST") {
        const promise = developersAxios().then(client => client.get("/governance/developers/clients"));

        promise.then(
            r => dispatch({type: "DEVELOPERS:FETCH-CLIENTS-LIST-SUCCESS", payload: r}),
            e => dispatch({type: "DEVELOPERS:FETCH-CLIENTS-LIST-ERROR", payload: e}));

        return next({type: "DEVELOPERS:FETCH-CLIENTS-LIST"});
    } else  if (type === "DEVELOPERS:CLIENTS-MANAGEMENT-SELECT-CLIENT") {
        const promise = developersAxios().then(client => client.get(`/governance/developers/clients/${payload.clientId}`));

        promise.then(
            r => dispatch({type: "DEVELOPERS:FETCH-CLIENT-DETAILS-SUCCESS", payload: r}),
            e => dispatch({type: "DEVELOPERS:FETCH-CLIENT-DETAILS-ERROR", payload: e}));

        return next({type: "DEVELOPERS:FETCH-CLIENT-DETAILS-PENDING", payload: {clientId: payload.clientId}});
    } else if (type === "DEVELOPERS:CLIENTS-MANAGEMENT-SAVE-CLIENT") {
        const {allowedCallbackUrls, allowedWebOrigins, allowedLogoutUrls, allowedCors} = payload.data;

        const splitString = (string) => string ? string.split(/,[\s]*/) : [];

        const patchData = {
            allowedCallbackUrls: splitString(allowedCallbackUrls),
            allowedWebOrigins: splitString(allowedWebOrigins),
            allowedLogoutUrls: splitString(allowedLogoutUrls),
            allowedCors: splitString(allowedCors),
        };
        const promise = developersAxios().then(client => client.patch(`/governance/developers/clients/${payload.clientId}`, patchData));

        promise.then(
            r => {

                dispatch({type: "DEVELOPERS:CLIENTS-MANAGEMENT-SAVE-CLIENT-SUCCESS", payload: r});

                setTimeout(() => {
                    dispatch({type: "DEVELOPERS:CLIENTS-MANAGEMENT-CLEAR-CLIENT-DETAILS-MESSAGE"})
                },4000)
            },
            e => dispatch({type: "DEVELOPERS:CLIENTS-MANAGEMENT-SAVE-CLIENT-ERROR", payload: e}));

        return next({type: "DEVELOPERS:CLIENTS-MANAGEMENT-SAVE-CLIENT"});
    }

    return next(action);
};
