import axios from "axios"
import * as actions from "./../../actions"
import json2csv from "json2csv";
import _ from "lodash";

const downloadAsCsv = ({fileName, data}) => {
    if (data.length === 0) return;
    const parser = new json2csv.Parser();

    if (window.navigator.msSaveOrOpenBlob) { //EDGE workaround
        const blob = new Blob([decodeURIComponent(encodeURI(parser.parse(data)))], {type: 'text/csv;charset=utf-8;'});
        navigator.msSaveBlob(blob, `${fileName}.csv`);
    } else {
        const element = document.createElement('a');
        element.setAttribute('href', 'data:text/plain;charset=utf-8,' + encodeURIComponent(parser.parse(data)));
        element.setAttribute('download', `${fileName}.csv`);
        element.style.display = 'none';
        document.body.appendChild(element);

        element.click();

        document.body.removeChild(element);
    }
};

export default ({dispatch, next, action, getState}) => {
    const {type} = action;

    if (type === "INTERNAL:OCCM-DEMO" && ! action.status) {
        const promise = axios.post(window.__react_app_portal_backend_base_url + "/portal/occm-demo-signup");

        promise.then(
            r => dispatch({type: "INTERNAL:OCCM-DEMO", status: actions.STATUS_SUCCESS, payload: r}),
            e => dispatch({type: "INTERNAL:OCCM-DEMO", status: actions.STATUS_ERROR, payload: e}));

        return next({type: "INTERNAL:OCCM-DEMO", status: actions.STATUS_PENDING});
    } else if (type === "INTERNAL:FETCH-WIDGET-README" && !action.status) {
        const promise = axios.get("/WIDGET_README.md", {baseURL: "/"});

        promise.then(
            r => dispatch({type: "INTERNAL:FETCH-WIDGET-README", status: actions.STATUS_SUCCESS, payload: r}),
            e => dispatch({type: "INTERNAL:FETCH-WIDGET-README", status: actions.STATUS_ERROR, payload: e}));

        return next({type: "INTERNAL:FETCH-WIDGET-README", status: actions.STATUS_PENDING});
    } else if(type === "INTERNAL:FETCH-AMERICAS-GLOBAL-SPIFF-DATA") {
        const promise = axios.get("/portal/americas-global-spiff");

        promise.then(
            r => dispatch({type: "INTERNAL:FETCH-AMERICAS-GLOBAL-SPIFF-DATA-SUCCESS", payload: r.data}),
            e => dispatch({type: "INTERNAL:FETCH-AMERICAS-GLOBAL-SPIFF-DATA-ERROR", payload: e})
        );

        return next({type: "INTERNAL:FETCH-AMERICAS-GLOBAL-SPIFF-DATA-PENDING"});
    } else if (type === "INTERNAL:DOWNLOAD-AMERICAS-GLOBAL-ACCOUNTS") {
        const data = _.get(getState(), "internal.americasGlobalSpiffData.accounts", []);
        downloadAsCsv({fileName: "accounts", data});
    }

    return next(action);
};
