import _ from 'lodash'
import * as actions from "../actions";

/*eslint default-case: 0*/

const defaultState = () => ({
    accountsManagement: {status: actions.STATUS_NOT_SENT}
});

export default (state = defaultState(), {payload, type}) => {
    switch (type) {
        case "ACCOUNTS-MANAGEMENT:SET-ACCOUNT-ID": {
            return { ...state, accountId: payload.accountId }
        }
        case "ACCOUNTS-MANAGEMENT:FETCH-DATA-PENDING": {
            return { ...state, loadingData: true }
        }
        case "ACCOUNTS-MANAGEMENT:FETCH-DATA-SUCCESS": {
            return {
                ...state,
                accountUsers: payload.users,
                accountWorkspaces: payload.workspaces,
                account: payload.account,
                accountManagementError: null,
                loadingData: null
            }
        }
        case "ACCOUNTS-MANAGEMENT:FETCH-DATA-ERROR": {
            return { ...state, accountManagementError: payload.errorMessage, loadingData: null }
        }
        case "ACCOUNTS-MANAGEMENT:OPEN-MANAGE-WORKSPACES": {
            return {
                ...state, manageWorkspaces: true,
                addUserOverlayState: null,
                userForWorkspacesManagement: null,
                userForRemoval: null
            }
        }
        case "ACCOUNTS-MANAGEMENT:CLOSE-MANAGE-WORKSPACES": {
            return {...state, manageWorkspaces: null}
        }
        case "ACCOUNTS-MANAGEMENT:OPEN-USER-MENU": {
            return {...state, currentUserMenu: payload}
        }
        case "ACCOUNTS-MANAGEMENT:CLOSE-USER-MENU": {
            return {...state, currentUserMenu: null}
        }
        case "ACCOUNTS-MANAGEMENT:OPEN-ASSOCIATED-WORKSPACES-POP-UP": {
            return {...state, currentUserWorkspacesPopUp: payload}
        }
        case "ACCOUNTS-MANAGEMENT:CLOSE-ASSOCIATED-WORKSPACES-POP-UP": {
            return {...state, currentUserWorkspacesPopUp: null}
        }
        case "ACCOUNTS-MANAGEMENT:REMOVE-USER-PROMPT": {
            return {...state, userForRemoval: payload}
        }
        case "ACCOUNTS-MANAGEMENT:REMOVE-USER-SUCCESS": {
            return {
                ...state,
                userForRemoval: null,
                accountUsers: _.without(state.accountUsers, _.find(state.accountUsers, { userPublicId: payload.associatedUserPublicId })),
                removeUserError: null
            }
        }
        case "ACCOUNTS-MANAGEMENT:REMOVE-USER-ERROR": {
            return { ...state, removeUserError: payload.errorMessage }
        }
        case "ACCOUNTS-MANAGEMENT:MANAGE-USER-WORKSPACES-PROMPT": {
            return {...state, userForWorkspacesManagement: payload}
        }
        case "ACCOUNTS-MANAGEMENT:MANAGE-USER-WORKSPACES-SUCCESS": {
            return { ...state, userForWorkspacesManagement: null, removeUserPending: true }
        }
        case "ACCOUNTS-MANAGEMENT:MANAGE-USER-WORKSPACES-ERROR": {
            return { ...state, manageUserWorkspacesError: payload.errorMessage, removeUserPending: true }
        }
        case "ACCOUNTS-MANAGEMENT:REMOVE-USER-PENDING": {
            return { ...state, manageUserWorkspacesError: null, removeUserPending: true }
        }
        case "ACCOUNTS-MANAGEMENT:EDIT-WORKSPACE-NAME-PENDING": {
            return { ...state, workspaceRenamePending: payload, manageWorkspaceError: null }
        }
        case "ACCOUNTS-MANAGEMENT:EDIT-WORKSPACE-NAME-SUCCESS": {
            return {...state, workspaceRenamePending: null}
        }
        case "ACCOUNTS-MANAGEMENT:EDIT-WORKSPACE-NAME-ERROR": {
            return { ...state, workspaceRenamePending: null, manageWorkspaceError: payload.errorMessage }
        }
        case "ACCOUNTS-MANAGEMENT:DELETE-WORKSPACE-PENDING": {
            return { ...state, workspaceDeletePending: payload, manageWorkspaceError: null }
        }
        case "ACCOUNTS-MANAGEMENT:DELETE-WORKSPACE-ERROR": {
            return { ...state, workspaceDeletePending: null, manageWorkspaceError: payload.errorMessage }
        }
        case "ACCOUNTS-MANAGEMENT:ADD-NEW-WORKSPACE-PENDING": {
            return { ...state, addNewWorkspacePending: true , manageWorkspaceError: null }
        }
        case "ACCOUNTS-MANAGEMENT:ADD-NEW-WORKSPACE-SUCCESS": {
            return {
                ...state,
                addNewWorkspacePending: null,
                accountWorkspaces: _.orderBy(state.accountWorkspaces.concat(payload), [workspace => workspace.workspaceName.toLowerCase()])
            }
        }
        case "ACCOUNTS-MANAGEMENT:ADD-NEW-WORKSPACE-ERROR": {
            return { ...state, addNewWorkspacePending: null, manageWorkspaceError: payload.errorMessage }
        }
        case "ACCOUNTS-MANAGEMENT:DISPLAY-WORKSPACES-ERROR": {
            return { ...state, manageWorkspaceError: payload.errorMessage }
        }
        case "ACCOUNTS-MANAGEMENT:SET-ADD-USER-OVERLAY-STATE": {
            return {
                ...state,
                addUserOverlayState: payload,
                associatedEmailInputFeedback: null,
                manageWorkspaces: null,
                userForWorkspacesManagement: null,
                userForRemoval: null
            }
        }
        case "ACCOUNTS-MANAGEMENT:CHECK-IF-ASSOCIATED-EMAIL-EXISTS-IN-CLOUD-CENTRAL-SUCCESS": {
            return {
                ...state,
                associatedEmailExistsInCloudCentral: payload,
                associatedEmailExistsInCloudCentralPending: null,
                associatedEmailInputFeedback: payload.valid ? '' : 'This Email doesn\'t exist in Cloud Central'
            }
        }
        case "ACCOUNTS-MANAGEMENT:CHECK-IF-ASSOCIATED-EMAIL-EXISTS-IN-CLOUD-CENTRAL-ERROR": {
            return {
                ...state,
                associatedEmailInputFeedback: payload.errorMessage,
                associatedEmailExistsInCloudCentralPending: null
            }
        }
        case "ACCOUNTS-MANAGEMENT:CHECK-IF-ASSOCIATED-EMAIL-EXISTS-IN-CLOUD-CENTRAL-PENDING": {
            return { ...state, associatedEmailExistsInCloudCentralPending: true }
        }
        case "ACCOUNTS-MANAGEMENT:SET-ASSOCIATED-EMAIL-INPUT-FEEDBACK": {
            return {...state, associatedEmailInputFeedback: payload}
        }
        case "ACCOUNTS-MANAGEMENT:ASSOCIATE-USER-PENDING": {
            return {...state, addUserPending: true}
        }
        case "ACCOUNTS-MANAGEMENT:ASSOCIATE-USER-SUCCESS": {
            return { ...state, addUserOverlayState: null, addUserPending: null }
        }
        case "ACCOUNTS-MANAGEMENT:ASSOCIATE-USER-ERROR": {
            return { ...state, addUserError: payload.errorMessage, addUserPending: null }
        }
        case "ACCOUNTS-MANAGEMENT:CLOSE-ALL-OVERLAYS": {
            return {
                ...state,
                currentUserMenu: null,
                currentUserWorkspacesPopUp: null,
                userForRemoval: null,
                userForWorkspacesManagement: null,
                manageWorkspaces: null,
                addUserOverlayState: null,
                associatedEmailInputFeedback: null
            }
        }
    }

    return state;
};
